<?xml version="1.0" encoding="UTF-8"?>
<!--
########################################################################
# metaf.xsl
#
# copyright (c) metaf2xml 2006-2009
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
########################################################################
-->

<xsl:stylesheet
    xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
    version = "1.0">

 <!-- set parameter with option "- -stringparam name value" of xsltproc -->
 <xsl:param name="lang"/>

 <xsl:variable name="NM2KM" select="1.852"/>
 <xsl:variable name="FT2M" select="0.3048"/>
 <xsl:variable name="SM2M" select="1609.34"/><!-- U.S. and int. statute mile -->
 <xsl:variable name="INHG2HPA" select="33.86388640341"/>

 <xsl:template match="data">
  <xsl:choose>
   <xsl:when test="$lang = 'en'">
    <xsl:apply-templates select="reports">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/en"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$lang = 'es'">
    <xsl:apply-templates select="reports">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/es"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$lang = 'ru'">
    <xsl:apply-templates select="reports">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/ru"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="reports">
     <xsl:with-param name="trans" select="document('metaf-lang.xsl')//trans/de"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="$method = 'html'">
   <xsl:comment> metaf: $Id: metaf.xsl,v 1.53 2009/02/28 09:37:05 metaf2xml Exp $ </xsl:comment>
   <xsl:text>&#10;</xsl:text>
   <xsl:comment>
    <xsl:value-of select="concat(' metaf-lang: ', document('metaf-lang.xsl')//trans/version, ' ')"/>
   </xsl:comment>
   <xsl:text>&#10;</xsl:text>
   <xsl:apply-templates select="version"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="reports">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="taf|metar|synop">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="version">
  <xsl:comment><xsl:value-of select="concat(' ', ., ' ')"/></xsl:comment>
  <xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="synop">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <table border="1" cellpadding="2">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="warning">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>SYNOP</b></td>
  </xsl:if>
  <th nowrap="1" colspan="3">
   <xsl:value-of select="$trans/hdr[@o='synop']"/>
   <xsl:choose>
    <xsl:when test="boolean(obsTime/hour) and (obsTime/hour/@v = '00' or obsTime/hour/@v = '06' or obsTime/hour/@v = '12' or obsTime/hour/@v = '18')">
     <xsl:value-of select="$trans/t[@o='synopMainHour']"/>
    </xsl:when>
    <xsl:when test="boolean(obsTime/hour) and (obsTime/hour/@v = '03' or obsTime/hour/@v = '09' or obsTime/hour/@v = '15' or obsTime/hour/@v = '21')">
     <xsl:value-of select="$trans/t[@o='synopIntermHour']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/t[@o='synopNonstandardHour']"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:apply-templates select="reportModifier">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:if test="$method != 'html'">
    <xsl:value-of select="concat('&#10;', $trans/hdr[@o='synop_ul'])"/>
   </xsl:if>
  </th>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(obsStationType)">
   <xsl:call-template name="section">
    <xsl:with-param name="trans" select="$trans"/>
    <xsl:with-param name="section_nr" select="0"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:apply-templates select="obsStationType|callSign|obsTime|windIndicator|stationPosition|obsStationId|precipInd|wxInd|baseLowestCloud|visPrev|visibilityAtLoc|totalCloudCover|sfcWind|temperature|stationPressure|SLPhPa|gpSurface|pressureChange|precipHourly|weatherSynop|cloudTypes|exactObsTime|section3|section4|section5">
   <xsl:with-param name="trans" select="$trans"/>
   <xsl:with-param name="type" select="obsStationType/stationType/@v"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position()!=last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="taf">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <table border="1" cellpadding="2">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="warning">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>TAF</b></td>
  </xsl:if>
  <th nowrap="1" colspan="3">
  <xsl:choose>
   <xsl:when test="not(boolean(fcstPeriod/hourFrom))">
    <xsl:value-of select="$trans/hdr[@o='taf']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="hours">
     <xsl:choose>
      <xsl:when test="boolean(fcstPeriod/dayFrom) and boolean(fcstPeriod/dayTill) and fcstPeriod/dayFrom/@v &lt;= fcstPeriod/dayTill/@v">
       <xsl:value-of select="fcstPeriod/hourTill/@v - fcstPeriod/hourFrom/@v + 24 * (fcstPeriod/dayTill/@v - fcstPeriod/dayFrom/@v)"/>
      </xsl:when>
      <!-- TODO: how to detect if dayFrom+1 > dayTill across end of month? -->
      <xsl:when test="boolean(fcstPeriod/dayFrom) and boolean(fcstPeriod/dayTill) and fcstPeriod/hourFrom/@v &lt; fcstPeriod/hourTill/@v">
       <xsl:value-of select="fcstPeriod/hourTill/@v - fcstPeriod/hourFrom/@v + 24"/>
      </xsl:when>
      <xsl:when test="fcstPeriod/hourFrom/@v &lt; fcstPeriod/hourTill/@v">
       <xsl:value-of select="fcstPeriod/hourTill/@v - fcstPeriod/hourFrom/@v"/>
      </xsl:when>
      <xsl:when test="boolean(fcstPeriod/dayFrom) and boolean(fcstPeriod/dayTill) and fcstPeriod/dayFrom/@v != fcstPeriod/dayTill/@v">
       <xsl:value-of select="fcstPeriod/hourTill/@v - fcstPeriod/hourFrom/@v + 24"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="fcstPeriod/hourTill/@v - fcstPeriod/hourFrom/@v + 24"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="concat(substring-before($trans/hdr[@o='taf_hour'], '|'), $hours, substring-after($trans/hdr[@o='taf_hour'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select="reportModifier">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="$method != 'html'">
   <xsl:value-of select="concat('&#10;', $trans/hdr[@o='taf_ul'])"/>
  </xsl:if>
  </th>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStationId|issueTime|fcstPeriod|fcstCancelled|fcstNotAvbl|sfcWind|CAVOK|visPrev|weather[position()=1]|cloud[position()=1]|visVert|turbulence|icing|windShearLvl|QNH|obscuration|tempAt|tempMaxAt|tempMinAt|correctedAt|amendedAt|limMetwatch|autoMetwatch|amendment|trend[position()=1]|tafRemark[position()=1]">
   <xsl:with-param name="type" select="'ICAO'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position()!=last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template match="metar">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <table border="1" cellpadding="2">
  <tr>
  <td colspan="4" style="font-family: monospace; font-size: 90%;">
  <xsl:value-of select="concat('msg: ', @s)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="warning">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <tr>
  <xsl:choose>
   <xsl:when test="boolean(isSpeci)">
    <xsl:if test="$method = 'html'">
     <td><b>SPECI</b></td>
    </xsl:if>
    <th nowrap="1" colspan="3">
     <xsl:value-of select="$trans/hdr[@o='speci']"/>
     <xsl:apply-templates select="reportModifier">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
     <xsl:if test="$method != 'html'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='speci_ul'])"/>
     </xsl:if>
    </th>
   </xsl:when>
   <xsl:otherwise>
    <xsl:if test="$method = 'html'">
     <td><b>METAR</b></td>
    </xsl:if>
    <th nowrap="1" colspan="3">
     <xsl:value-of select="$trans/hdr[@o='metar']"/>
     <xsl:apply-templates select="reportModifier">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
     <xsl:if test="$method != 'html'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='metar_ul'])"/>
     </xsl:if>
    </th>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="obsStationId|obsTime|sfcWind|CAVOK|visPrev|visRwy|RVRNO|weather[position()=1]|cloud[position()=1]|visVert|temperature|QNH|windShear|rwyState|somePressure|recentWeather[position()=1]|colourCode|cloudMaxCover|NEFO_PLAYA|RH|windAtLoc|rwyWind|trend[position()=1]|remark[position()=1]">
   <xsl:with-param name="type" select="'ICAO'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:apply-templates select="ERROR">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </table>
  <xsl:text>&#10;</xsl:text>
  <xsl:if test="position()!=last()"><br /></xsl:if>
 </xsl:template>

 <xsl:template name="unitConverter">
  <xsl:param name="val"/>
  <xsl:param name="unit"/>
  <xsl:param name="factor"/>
  <xsl:param name="format"/>
  <xsl:param name="trans"/>
  <xsl:if test="$val/@q = 'isEqualGreater'">&gt;=</xsl:if>
  <xsl:if test="$val/@q = 'isLess'">&lt;</xsl:if>
  <xsl:if test="$val/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:choose>
   <xsl:when test="$unit = '' or $val/@u = $unit">
    <xsl:value-of select="$val/@v"/>
    <xsl:if test="boolean($val/@rp)">
     <xsl:value-of select="concat(' (.. &lt;', $val/@v + $val/@rp, ')')"/>
    </xsl:if>
    <xsl:value-of select="$trans/units[@o=$val/@u]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="conv_rate">
     <xsl:choose>
      <xsl:when test="$val/@u = 'IN' and $unit = 'MM'">
       <xsl:value-of select="$FT2M div 12 * 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MM' and $unit = 'IN'">
       <xsl:value-of select="12 div $FT2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'IN' and $unit = 'CM'">
       <xsl:value-of select="$FT2M div 12 * 100"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'CM' and $unit = 'IN'">
       <xsl:value-of select="12 div $FT2M div 100"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'M'">
       <xsl:value-of select="$FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'FT'">
       <xsl:value-of select="1 div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'KM'">
       <xsl:value-of select="$FT2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'FT'">
       <xsl:value-of select="1000 div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'NM' and $unit = 'M'">
       <xsl:value-of select="$NM2KM * 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'NM'">
       <xsl:value-of select="1 div 1000 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'NM' and $unit = 'KM'">
       <xsl:value-of select="$NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'NM'">
       <xsl:value-of select="1 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'FT' and $unit = 'SM'">
       <xsl:value-of select="$FT2M div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'FT'">
       <xsl:value-of select="$SM2M div $FT2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'M'">
       <xsl:value-of select="$SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'M' and $unit = 'SM'">
       <xsl:value-of select="1 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'SM' and $unit = 'KM'">
       <xsl:value-of select="$SM2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KM' and $unit = 'SM'">
       <xsl:value-of select="1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'KMH'">
       <xsl:value-of select="$NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'KT'">
       <xsl:value-of select="1 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'MPH'">
       <xsl:value-of select="1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'KMH'">
       <xsl:value-of select="$SM2M div 1000"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KMH' and $unit = 'MPS'">
       <xsl:value-of select="1 div 3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'KMH'">
       <xsl:value-of select="3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'KT'">
       <xsl:value-of select="3.6 div $NM2KM"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'MPS'">
       <xsl:value-of select="$NM2KM div 3.6"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPS' and $unit = 'MPH'">
       <xsl:value-of select="3600 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'MPS'">
       <xsl:value-of select="$SM2M div 3600"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'KT' and $unit = 'MPH'">
       <xsl:value-of select="$NM2KM * 1000 div $SM2M"/>
      </xsl:when>
      <xsl:when test="$val/@u = 'MPH' and $unit = 'KT'">
       <xsl:value-of select="$SM2M div $NM2KM div 1000"/>
      </xsl:when>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="format-number($val/@v div $factor * $conv_rate, $format)"/>
    <xsl:if test="$factor = 10 and not($val/@v = '0')">
     <xsl:text>0</xsl:text>
    </xsl:if>
    <xsl:value-of select="$trans/units[@o=$unit]"/>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="reportModifier">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:text>&#9;&#9;(</xsl:text>
  <xsl:value-of select="$trans/reportModifierType[@o=$this/modifierType/@v]"/>
  <xsl:if test="modifierType/@v = 'P'">
   <xsl:value-of select="concat($trans/t[@o='segment'],' ', segment/@v)"/>
    <xsl:if test="boolean(isLastSegment)">
     <xsl:value-of select="concat(' (', $trans/t[@o='last'],')')"/>
    </xsl:if>
  </xsl:if>
  <xsl:if test="boolean(over24hLate)">
   <xsl:value-of select="$trans/t[@o='over24hLate']"/>
  </xsl:if>
  <xsl:if test="boolean(sequenceLost)">
   <xsl:value-of select="$trans/t[@o='sequenceLost']"/>
  </xsl:if>
  <xsl:if test="boolean(bulletinSeq)">
   <xsl:value-of select="concat($trans/t[@o='bulletinSeq'], bulletinSeq/@v)"/>
  </xsl:if>
  <xsl:text>)</xsl:text>
 </xsl:template>

 <xsl:template match="precipInd">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:call-template name="section">
   <xsl:with-param name="trans" select="$trans"/>
   <xsl:with-param name="section_nr" select="1"/>
  </xsl:call-template>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='precipIndicator']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/precipIndicator[@o=$this/precipIndVal/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="wxInd">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='wxIndicator']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/wxIndicator[@o=$this/wxIndVal/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="baseLowestCloud">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:if test="boolean(to)">
      <xsl:attribute name="rowspan">2</xsl:attribute>
     </xsl:if>
     <b><xsl:value-of select="@s"/></b>
    </xsl:element>
   </xsl:if>
   <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='baseLowestCloud']"/></td>
   <xsl:choose>
    <xsl:when test="boolean(notAvailable)">
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="from"/>
      <xsl:with-param name="unit" select="'M'"/>
      <xsl:with-param name="factor" select="10"/>
      <xsl:with-param name="format" select="'0'"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="from"/>
      <xsl:with-param name="unit" select="'FT'"/>
      <xsl:with-param name="factor" select="10"/>
      <xsl:with-param name="format" select="'0'"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
     </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(to)">
   <tr>
    <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='to']"/></td>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="to"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="to"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="stationPosition">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='stationPosition']"/>
   </td>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="lat/@v &lt; 0">
     <xsl:value-of select="format-number(-lat/@v, '0.0° S')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(lat/@v, '0.0° N')"/>
     <!--xsl:value-of select="concat(format-number(lat/@v - lat/@v mod 1, '00'), format-number((lat/@v mod 1) * 60, '00N'))"/-->
    </xsl:otherwise>
   </xsl:choose>
   <xsl:choose>
    <xsl:when test="lon/@v &lt; 0">
     <xsl:value-of select="format-number(-lon/@v, ' 0.0° W')"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="format-number(lon/@v, ' 0.0° E')"/>
    </xsl:otherwise>
   </xsl:choose>
   <xsl:if test="boolean(region)">
    <xsl:value-of select="concat(' (', $trans/wmoRegion[@o=$this/region/@v], ')')"/>
   </xsl:if>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="totalCloudCover">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='totalCloudCover']"/>
   </td>
   <td nowrap="1" colspan="2">
   <xsl:call-template name="cloudOktas">
    <xsl:with-param name="cloudOktas" select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="gpSurface">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:choose>
    <xsl:when test="boolean(geopotential)">
     <xsl:value-of select="concat(substring-before($trans/hdr[@o='gpSurface'], '|'), surface/@v, substring-after($trans/hdr[@o='gpSurface'], '|'))"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/hdr[@o='gpSurfaceNA']"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="boolean(invalidFormat)">
     <xsl:apply-templates select="invalidFormat">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="concat(geopotential/@v, $trans/units[@o='gpm'])"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weatherSynop|weatherSynopAdd|weatherSynopAmplPast|weatherSynopAmpl|weatherSynopPast">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="name(.) = 'weatherSynop'">
     <xsl:choose>
      <xsl:when test="boolean(weatherPast1) and boolean(weatherPast2NotAvailable)">3</xsl:when>
      <xsl:when test="boolean(weatherPast2) and boolean(weatherPast1NotAvailable)">3</xsl:when>
      <xsl:when test="boolean(weatherPast1) and boolean(weatherPast2) and weatherPast1/@v != weatherPast2/@v">3</xsl:when>
      <xsl:otherwise>2</xsl:otherwise>
     </xsl:choose>
    </xsl:when>
    <xsl:when test="boolean(weatherSynopFG/visVertFrom)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="name(.) = 'weatherSynop'">
    <xsl:value-of select="$trans/hdr[@o='weather']"/>
   </xsl:when>
   <xsl:when test="name(.) = 'weatherSynopPast'">
    <xsl:value-of select="substring-before($trans/hdr[@o=name($this)], '|')"/>
    <xsl:apply-templates select="timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
     <xsl:with-param name="period" select="period"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    <xsl:value-of select="substring-after($trans/hdr[@o=name($this)], '|')"/>
   </xsl:when>
   <xsl:when test="name(.) = 'weatherSynopAmpl'">
    <xsl:value-of select="concat(substring-before($trans/hdr[@o='weatherSynopAmpl'], '|'), $trans/durationSince[@o=$this/period/@v], substring-after($trans/hdr[@o='weatherSynopAmpl'], '|'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="boolean(weatherSynopFG)">
   <xsl:value-of select="$trans/hdr[@o='weatherSynopFG']"/>
  </xsl:if>
  </td>
  <xsl:choose>
   <xsl:when test="boolean(weatherPresentNotAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherPresent)">
    <td nowrap="1" colspan="2">
    <xsl:choose>
     <xsl:when test="../wxInd/wxIndVal/@v = 7">
      <xsl:value-of select="$trans/weatherSynopAuto[@o=$this/weatherPresent/@v]"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/weatherSynop[@o=$this/weatherPresent/@v]"/>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherPresent1)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/weatherSynop1[@o=$this/weatherPresent1/@v]"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(weatherSynopFG)">
    <xsl:if test="boolean(weatherSynopFG/visVert)">
     <xsl:call-template name="visibility">
      <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
      <xsl:with-param name="visVal" select="weatherSynopFG/visVert"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:if>
    <xsl:if test="boolean(weatherSynopFG/visVertFrom)">
     <xsl:call-template name="visibility">
      <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
      <xsl:with-param name="visVal" select="weatherSynopFG/visVertFrom"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:if>
   </xsl:when>
   <xsl:when test="boolean(weatherSynopPrecip)">
    <td nowrap="1" colspan="2">
    <xsl:call-template name="printWeather">
     <xsl:with-param name="this" select="weatherSynopPrecip"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    <xsl:value-of select="$trans/hdr[@o='weatherSynopPrecip']"/>
    <xsl:if test="boolean(weatherSynopPrecip/rateOfFall)">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="weatherSynopPrecip/rateOfFall"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:if>
    <xsl:if test="boolean(weatherSynopPrecip/rateOfFallFrom)">
     <xsl:value-of select="concat(weatherSynopPrecip/rateOfFallFrom/@v, ' - ', weatherSynopPrecip/rateOfFallTo/@v)"/>
     <xsl:value-of select="$trans/units[@o=$this/weatherSynopPrecip/rateOfFallFrom/@u]"/>
    </xsl:if>
    </td>
   </xsl:when>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="name(.) = 'weatherSynop'">
   <tr>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows - 1"/></xsl:attribute>
    <xsl:value-of select="concat(substring-before($trans/hdr[@o='weatherPast'], '|'), $trans/durationSince[@o=$this/period/@v], substring-after($trans/hdr[@o='weatherPast'], '|'))"/>
   </xsl:element>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="boolean(weatherPast1NotAvailable)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="../wxInd/wxIndVal/@v = 7">
     <xsl:value-of select="$trans/weatherSynopPastAuto[@o=$this/weatherPast1/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/weatherSynopPast[@o=$this/weatherPast1/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(weatherSynopFG/visVertTo)">
   <tr>
   <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='to']"/></td>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="weatherSynopFG/visVertTo"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="$rows = 3">
   <tr><td nowrap="1" colspan="2">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="boolean(weatherPast2NotAvailable)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="../wxInd/wxIndVal/@v = 7">
     <xsl:value-of select="$trans/weatherSynopPastAuto[@o=$this/weatherPast2/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/weatherSynopPast[@o=$this/weatherPast2/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="section">
  <xsl:param name="trans"/>
  <xsl:param name="s"/>
  <xsl:param name="section_nr"/>
  <xsl:if test="$method = 'html'">
   <tr>
   <xsl:choose>
    <xsl:when test="$s != ''">
     <td nowrap="1"><b><xsl:value-of select="$s"/></b></td>
    </xsl:when>
    <xsl:otherwise>
     <td></td>
    </xsl:otherwise>
   </xsl:choose>
   <td nowrap="1" colspan="3"><b>
    <xsl:value-of select="concat($trans/t[@o='section'], ' ', $section_nr, ':')"/>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="windIndicator">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='windIndicator']"/>
   </td>
   <td nowrap="1" colspan="2">
   <xsl:choose>
    <xsl:when test="boolean(notAvailable)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/units[@o=$this/windUnit/@v]"/>
     <xsl:if test="boolean(isEstimated)">
      <xsl:value-of select="concat(', ', $trans/t[@o='estimated'])"/>
     </xsl:if>
    </xsl:otherwise>
   </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsStationId|callSign">
  <xsl:param name="type"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
   </td>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="id/@v"/>
   <xsl:if test="boolean(region)">
    <xsl:value-of select="concat(' (', $trans/wmoRegion[@o=$this/region/@v], ')')"/>
   </xsl:if>
   <xsl:choose>
    <xsl:when test="name($this) = 'callSign'">
     <xsl:call-template name="stationInfo">
      <xsl:with-param name="station" select="document('stations.xml')//stations/id[@callsign=$this/id/@v]"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:when test="$type = 'ICAO'">
     <xsl:call-template name="stationInfo">
      <xsl:with-param name="station" select="document('stations.xml')//stations/id[@icao=$this/id/@v]"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:when test="$type = 'AAXX'">
     <xsl:call-template name="stationInfo">
      <xsl:with-param name="station" select="document('stations.xml')//stations/id[@wmo=$this/id/@v]"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:when test="$type = 'BBXX'">
     <xsl:call-template name="stationInfo">
      <xsl:with-param name="station" select="document('stations.xml')//stations/id[@ship=$this/id/@v]"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:when>
   </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="stationInfo">
  <xsl:param name="trans"/>
  <xsl:param name="station"/>
  <xsl:if test="boolean($station)">
   <xsl:value-of select="concat(' (', $station, ', ', $trans/country[@o=$station/@ctry], ')')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="fcstPeriod">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='fcstPeriod']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(invalidFormat)">
    <xsl:apply-templates select="invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="boolean(day)">
    <xsl:value-of select="concat(format-number(day/@v, '0'), '., ', hourFrom/@v, ':00 - ', hourTill/@v, ':00 UTC')"/>
    <xsl:if test="hourFrom/@v &gt;= hourTill/@v">
     <xsl:value-of select="$trans/t[@o='nextDay']"/>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(format-number(dayFrom/@v, '0'), '., ', hourFrom/@v, ':00 - ', format-number(dayTill/@v, '0'), '., ', hourTill/@v, ':00 UTC')"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsTime|issueTime|exactObsTime">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
   </td>
   <td nowrap="1" colspan="2">
    <xsl:choose>
     <xsl:when test="boolean(invalidFormat)">
      <xsl:apply-templates select="invalidFormat">
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:apply-templates>
     </xsl:when>
     <xsl:otherwise>
      <xsl:if test="boolean(day)">
       <xsl:value-of select="substring-before($trans/t[@o='onThe'], '|')"/>
       <xsl:value-of select="format-number(day/@v, '0')"/>
       <xsl:value-of select="substring-after($trans/t[@o='onThe'], '|')"/>
      </xsl:if>
      <xsl:value-of select="concat(hour/@v, ':', minute/@v, ' UTC')"/>
     </xsl:otherwise>
    </xsl:choose>
   </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visPrev">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(NDV) and boolean(../visMin)">3</xsl:when>
    <xsl:when test="boolean(NDV) or  boolean(../visMin)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="str">
   <xsl:choose>
    <xsl:when test="boolean(../visMin)">
     <xsl:value-of select="concat(@s, ' ', ../visMin/@s)"/>
    </xsl:when>
    <xsl:otherwise><xsl:value-of select="@s"/></xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="$str"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='visPrev']"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(NDV)">
   <tr><td nowrap="1" colspan="2">
   <xsl:value-of select="concat('&#9;&#9;&#9;', $trans/t[@o='NDV'])"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(../visMin)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
    <xsl:with-param name="visVal" select="../visMin"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visVert">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='visVert']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visRwy">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr" select="$trans/hdr[@o='visRwy']"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(RVRVariations) and boolean(visTrend)">3</xsl:when>
    <xsl:when test="boolean(RVRVariations) or  boolean(visTrend)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="concat(substring-before($hdr, '|'), rwyDesig/@v, substring-after($hdr, '|'))"/>
   <xsl:with-param name="rows" select="$rows"/>
  </xsl:call-template>
  <xsl:variable name="from">
   <xsl:choose>
    <xsl:when test="boolean(RVRVariations)">
     <xsl:value-of select="concat($trans/t[@o='variable-from'], ' ')"/>
    </xsl:when>
    <xsl:otherwise><xsl:text></xsl:text></xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
   <xsl:with-param name="fromto" select="$from"/>
   <xsl:with-param name="visVal" select="RVR"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(RVRVariations)">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='rwyVisNotAvailable']"/>
    <xsl:with-param name="fromto" select="concat($trans/t[@o='variable-to'], ' ')"/>
    <xsl:with-param name="visVal" select="RVRVariations"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(visTrend)">
   <tr>
   <td nowrap="1" colspan="2">
    <xsl:value-of select="concat($trans/hdr[@o='visTrend'], $trans/visTrend[@o=$this/visTrend/@v])"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(RVRVariations) or boolean(visTrend)"><xsl:text>&#10;</xsl:text></xsl:if>
 </xsl:template>

 <xsl:template name="visibility_str">
  <xsl:param name="rows"/>
  <xsl:param name="str"/>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="$str"/></b>
   </xsl:element>
  </xsl:if>
 </xsl:template>

 <xsl:template name="visibility_header">
  <xsl:param name="header"/>
  <xsl:param name="rows"/>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$header"/>
  </xsl:element>
 </xsl:template>

 <xsl:template name="visibility">
  <xsl:param name="notavail"/>
  <xsl:param name="fromto"/>
  <xsl:param name="visVal"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="boolean($visVal/invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    </td>
   </xsl:when>
   <xsl:when test="boolean($visVal/notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$notavail"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="$fromto"/>
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="$visVal/distance"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    <xsl:if test="boolean($visVal/compassDir)">
     <xsl:value-of select="substring-before($trans/t[@o='compassDirTo'], '|')"/>
     <xsl:value-of select="substring-before($trans/t[@o='compassDirDescr'], '|')"/>
     <xsl:value-of select="$trans/compassDir[@o=$visVal/compassDir/@v]"/>
     <xsl:value-of select="substring-after($trans/t[@o='compassDirDescr'], '|')"/>
     <xsl:value-of select="substring-after($trans/t[@o='compassDirTo'], '|')"/>
    </xsl:if>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="($visVal/distance/@u = 'M' and $visVal/distance/@v &lt; 2000) or ($visVal/distance/@u = 'KM' and $visVal/distance/@v &lt; 2)">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'FT'"/>
       <xsl:with-param name="factor" select="10"/>
       <xsl:with-param name="format" select="'0'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="$visVal/distance/@u = 'KM' or $visVal/distance/@u = 'M'">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'SM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="($visVal/distance/@u = 'FT' and $visVal/distance/@v &lt; 6000) or (($visVal/distance/@u = 'SM' or $visVal/distance/@u = 'NM') and $visVal/distance/@v &lt; 2)">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'M'"/>
       <xsl:with-param name="factor" select="10"/>
       <xsl:with-param name="format" select="'0'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="$visVal/distance"/>
       <xsl:with-param name="unit" select="'KM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="boolean($visVal/compassDir)">
     <xsl:value-of select="substring-before($trans/t[@o='compassDirTo'], '|')"/>
     <xsl:value-of select="substring-before($trans/t[@o='compassDirDescr'], '|')"/>
     <xsl:value-of select="$trans/compassDir[@o=$visVal/compassDir/@v]"/>
     <xsl:value-of select="substring-after($trans/t[@o='compassDirDescr'], '|')"/>
     <xsl:value-of select="substring-after($trans/t[@o='compassDirTo'], '|')"/>
    </xsl:if>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printTime">
  <xsl:param name="time"/>
  <xsl:param name="trans"/>
  <xsl:value-of select="substring-before($trans/t[@o='time-at'], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean($time/hour)">
    <xsl:value-of select="concat(format-number($time/hour/@v, '00'), ':', format-number($time/minute/@v, '00 UTC'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(substring-before($trans/t[@o='afterHour'], '|'), format-number($time/minute/@v, '0'), substring-after($trans/t[@o='afterHour'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/t[@o='time-at'], '|')"/>
 </xsl:template>

 <xsl:template match="peakWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr">
   <xsl:value-of select="substring-before($trans/hdr[@o='peakWind'], '|')"/>
   <xsl:if test="boolean(minute)">
    <xsl:call-template name="printTime">
     <xsl:with-param name="time"  select="."/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:if>
   <xsl:value-of select="substring-after($trans/hdr[@o='peakWind'], '|')"/>
  </xsl:variable>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$hdr"/>
   <xsl:with-param name="s"     select="@s"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="rwyWind|thrWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="concat(substring-before($trans/hdr[@o=name($this)], '|'), rwyDesig/@v, substring-after($trans/hdr[@o=name($this)], '|'))"/>
   <xsl:with-param name="s"     select="@s"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="sfcWind|gridWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$trans/hdr[@o=name($this)]"/>
   <xsl:with-param name="s"     select="@s"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="windAtLoc">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="loc">
   <xsl:choose>
    <xsl:when test="windLocation/@v = 'RS'">
     <xsl:value-of select="$trans/t[@o='RS']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="windLocation/@v"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="concat(substring-before($trans/hdr[@o=name($this)], '|'), $loc, substring-after($trans/hdr[@o=name($this)], '|'))"/>
   <xsl:with-param name="s"     select="@s"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="wind">
  <xsl:param name="hdr"/>
  <xsl:param name="s"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(gustSpeed) and boolean(windVarLeft)">3</xsl:when>
    <xsl:when test="boolean(gustSpeed) or  boolean(windVarLeft)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
   <xsl:if test="$method = 'html' and $s != ''">
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     <b><xsl:value-of select="$s"/></b>
    </xsl:element>
   </xsl:if>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:value-of select="$hdr"/>
   </xsl:element>
   <xsl:choose>
    <xsl:when test="boolean(invalidFormat)">
     <td nowrap="1" colspan="2">
     <xsl:apply-templates select="invalidFormat">
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
     </td>
    </xsl:when>
    <xsl:when test="boolean(notAvailable)">
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </td>
    </xsl:when>
    <xsl:when test="boolean(isCalm)">
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='calm']"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <xsl:variable name="dir">
      <xsl:choose>
       <xsl:when test="boolean(dirNotAvailable)">
        <xsl:value-of select="$trans/t[@o='dirNotAvailable']"/>
       </xsl:when>
       <xsl:when test="boolean(dirVariable)">
        <xsl:value-of select="$trans/t[@o='dirVariable']"/>
       </xsl:when>
       <xsl:when test="boolean(dirVarAllUnk)">
        <xsl:value-of select="$trans/t[@o='dirVarAllUnk']"/>
       </xsl:when>
       <xsl:when test="boolean(dir)">
        <xsl:value-of select="concat($trans/t[@o='wind-from'],' ')"/>
        <xsl:value-of select="$trans/compassDir16/arr[position()=1+format-number($this/dir/@v div 45 * 2, '0')]"/>
        <xsl:value-of select="concat(' (', dir/@v, '°')"/>
        <xsl:choose>
         <xsl:when test="boolean(dir/@rp) and boolean(dir/@rn)">
          <xsl:value-of select="concat(' (+', dir/@rp, '°/-', dir/@rn, '°)')"/>
         </xsl:when>
         <xsl:when test="boolean(dir/@rp)">
          <xsl:value-of select="concat(' (+', dir/@rp, '°)')"/>
         </xsl:when>
         <xsl:when test="boolean(dir/@rn)">
          <xsl:value-of select="concat(' (-', dir/@rn, '°)')"/>
         </xsl:when>
        </xsl:choose>
        <xsl:text>)</xsl:text>
       </xsl:when>
      </xsl:choose>
     </xsl:variable>
     <xsl:choose>
      <xsl:when test="boolean(speedNotAvailable)">
       <td nowrap="1" colspan="2">
       <xsl:value-of select="$dir"/>
       <xsl:if test="not(boolean(dirNotAvailable))">
        <xsl:text>,</xsl:text>
       </xsl:if>
       <xsl:value-of select="$trans/t[@o='speedNotAvailable']"/>
       </td>
      </xsl:when>
      <xsl:otherwise>
       <xsl:call-template name="printSpeed">
        <xsl:with-param name="dir" select="$dir"/>
        <xsl:with-param name="speed" select="speed"/>
        <xsl:with-param name="delim" select="'&#9;&#9;'"/>
        <xsl:with-param name="trans" select="$trans"/>
       </xsl:call-template>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:otherwise>
   </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(gustSpeed)">
   <tr>
   <xsl:call-template name="printSpeed">
    <xsl:with-param name="dir" select="$trans/t[@o='wind-gusts']"/>
    <xsl:with-param name="speed" select="gustSpeed"/>
    <xsl:with-param name="delim" select="'&#9;&#9;&#9;'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(windVarLeft)">
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="concat($trans/t[@o='variable'], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-from'],' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[position()=1+format-number($this/windVarLeft/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat($trans/t[@o='variable-to'], ' ')"/>
   <xsl:value-of select="concat($trans/compassDir16/arr[position()=1+format-number($this/windVarRight/@v div 45 * 2, '0')], ' ')"/>
   <xsl:value-of select="concat('(', windVarLeft/@v, '°--', windVarRight/@v, '°)')"/>
   </td></tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printSpeed">
  <xsl:param name="dir"/>
  <xsl:param name="speed"/>
  <xsl:param name="delim"/>
  <xsl:param name="greater"/>
  <xsl:param name="trans"/>
  <td nowrap="1">
  <xsl:if test="$dir != ''">
   <xsl:value-of select="concat($dir, ' ', $trans/t[@o='wind-at'], ' ')"/>
  </xsl:if>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'KMH'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  <xsl:value-of select="$delim"/>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'KT'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:text> = </xsl:text>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'MPH'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:text> = </xsl:text>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="$speed"/>
   <xsl:with-param name="unit" select="'MPS'"/>
   <xsl:with-param name="factor" select="1"/>
   <xsl:with-param name="format" select="'0.#'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
 </xsl:template>

 <!-- combine all weather nodes into one set and process them in one go -->
 <xsl:template match="weather">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="../weather" mode="go">
   <xsl:with-param name="s">
    <xsl:apply-templates select="../weather" mode="concat_s"/>
   </xsl:with-param>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="recentWeather">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="../recentWeather" mode="go">
   <xsl:with-param name="s">
    <xsl:apply-templates select="../recentWeather" mode="concat_s"/>
   </xsl:with-param>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="weather|recentWeather|cloud" mode="concat_s">
  <xsl:value-of select="concat(' ', @s)"/>
 </xsl:template>

 <xsl:template match="weather|recentWeather" mode="go">
  <xsl:param name="s"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <tr>
    <xsl:if test="$method = 'html'">
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
      <b><xsl:value-of select="substring($s, 2)"/></b>
     </xsl:element>
    </xsl:if>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
     <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
    </xsl:element>
    <td nowrap="1" colspan="2">
    <xsl:call-template name="printWeather">
     <xsl:with-param name="this" select="."/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td></tr>
   </xsl:when>
   <xsl:otherwise>
    <tr><td nowrap="1" colspan="2">
    <xsl:if test="$method = 'text'">, </xsl:if>
    <xsl:call-template name="printWeather">
     <xsl:with-param name="this" select="."/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td></tr>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:if test="position() = last()">
   <xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printWeather">
  <xsl:param name="this"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="boolean($this/notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean($this/invalidFormat)">
    <xsl:apply-templates select="$this/invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="boolean($this/NSW)">
    <xsl:value-of select="$trans/weather[@o='NSW']"/>
   </xsl:when>
   <xsl:when test="boolean($this/tornado)">
    <xsl:value-of select="$trans/weather[@o='tornado']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="w_all">
     <xsl:apply-templates select="$this/descriptor"/>
     <xsl:apply-templates select="$this/phenomenon"/>
    </xsl:variable>
    <xsl:variable name="phenomDescr">
     <xsl:if test="boolean($this/phenomDescr)">
      <xsl:value-of select="concat($trans/t[@o=$this/phenomDescr/@v], ' ')"/>
     </xsl:if>
    </xsl:variable>
    <xsl:variable name="w_all_trans">
     <xsl:choose>
      <xsl:when test="$trans/weather[@o=$w_all] != ''">
       <xsl:variable name="w_trans" select="$trans/weather[@o=$w_all]"/>
       <xsl:value-of select="concat(substring-before($w_trans, '|'), $phenomDescr, substring-after($w_trans, '|'))"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$this/@s"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:value-of select="$w_all_trans"/>
    <xsl:if test="boolean($this/inVicinity)">
     <xsl:value-of select="$trans/t[@o='inVicinity']"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="descriptor|phenomenon">
  <xsl:value-of select="@v"/>
 </xsl:template>

 <xsl:template match="cloud" mode="ceiling">
  <xsl:param name="trans"/>
  <xsl:if test="boolean(isCeiling) and cloudBase/@u = 'FT'">
   <xsl:value-of select="cloudBase/@v"/>
  </xsl:if>
 </xsl:template>

 <!-- combine all cloud nodes into one set and process them in one go -->
 <xsl:template match="cloud">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="../cloud" mode="go">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="cloud" mode="go">
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="position() = 1">
   <xsl:variable name="ceiling">
    <xsl:apply-templates select="../cloud" mode="ceiling"/>
   </xsl:variable>
    <xsl:variable name="rows">
     <xsl:choose>
      <xsl:when test="$ceiling != ''"><xsl:value-of select="last() + 1"/></xsl:when>
      <xsl:otherwise><xsl:value-of select="last()"/></xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <tr>
    <xsl:if test="$method = 'html'">
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
      <b><xsl:apply-templates select="../cloud" mode="concat_s"/></b>
     </xsl:element>
    </xsl:if>
    <xsl:choose>
     <xsl:when test="$ceiling != ''">
      <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='ceiling']"/></td>
      <td nowrap="1">
      <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ', $ceiling, $trans/units[@o='FT'])"/>
      </td>
      <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
      <td nowrap="1">
      <xsl:value-of select="concat(format-number($ceiling div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
      </td>
     </xsl:when>
     <xsl:otherwise>
      <xsl:element name="td">
       <xsl:attribute name="nowrap">1</xsl:attribute>
       <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
       <xsl:value-of select="$trans/hdr[@o='cloud']"/>
      </xsl:element>
      <xsl:call-template name="printCloud">
       <xsl:with-param name="at_abv" select="'cloud-at'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    </tr><xsl:text>&#10;</xsl:text>
    <xsl:if test="$ceiling != ''">
     <tr>
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
      <xsl:value-of select="$trans/hdr[@o='cloud']"/>
     </xsl:element>
     <xsl:call-template name="printCloud">
      <xsl:with-param name="at_abv" select="'cloud-at'"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
     </tr><xsl:text>&#10;</xsl:text>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <tr>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printCloud">
  <xsl:param name="trans"/>
  <xsl:param name="at_abv"/>
  <xsl:variable name="this" select="."/>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    </td>
   </xsl:when>
   <xsl:when test="boolean(noClouds)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/cloudCover[@o=$this/noClouds/@v]"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:if test="not(boolean(cloudBase))">
      <xsl:attribute name="colspan">2</xsl:attribute>
     </xsl:if>
     <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
     <xsl:choose>
      <xsl:when test="boolean(cloudBase)">
       <xsl:value-of select="concat(' ', $trans/t[@o=$at_abv], ' ')"/>
       <xsl:call-template name="unitConverter">
        <xsl:with-param name="val" select="cloudBase"/>
        <xsl:with-param name="unit" select="'FT'"/>
        <xsl:with-param name="factor" select="10"/>
        <xsl:with-param name="format" select="'0'"/>
        <xsl:with-param name="trans" select="$trans"/>
       </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="concat(', ', $trans/t[@o='baseBelowStation'])"/>
      </xsl:otherwise>
     </xsl:choose>
     <xsl:if test="boolean(cloudType)">
      <br />
      <xsl:value-of select="concat(' (', $trans/cloudType[@o=$this/cloudType/@v], ')')"/>
     </xsl:if>
     <xsl:if test="boolean(cloudTypeNotAvailable)">
      <xsl:value-of select="concat(' ', $trans/t[@o='cloudTypeNotAvailable'])"/>
     </xsl:if>
    </xsl:element>
    <xsl:if test="boolean(cloudBase)">
     <xsl:text>&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:call-template name="unitConverter">
      <xsl:with-param name="val" select="cloudBase"/>
      <xsl:with-param name="unit" select="'M'"/>
      <xsl:with-param name="factor" select="10"/>
      <xsl:with-param name="format" select="'0'"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
     </td>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="temperature">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(air) and boolean(dewpoint) and boolean(relHumid1)">3</xsl:when>
    <xsl:when test="boolean(air) and (boolean(dewpoint) or boolean(relHumid1))">2</xsl:when>
    <xsl:when test="boolean(dewpoint) and boolean(relHumid1)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="boolean(air)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-temp']"/>
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(dewpoint)">
   <tr>
   <xsl:choose>
    <xsl:when test="boolean(air)">
     <xsl:call-template name="printTemp">
      <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
      <xsl:with-param name="temp" select="dewpoint"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
     <xsl:call-template name="printTemp">
      <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
      <xsl:with-param name="rows" select="$rows"/>
      <xsl:with-param name="s" select="@s"/>
      <xsl:with-param name="temp" select="dewpoint"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:call-template>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(relHumid1)">
   <tr>
   <xsl:if test="$method = 'html' and not(boolean(air)) and not(boolean(dewpoint))">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
   <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='relHumid']"/></td>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="format-number(relHumid1/@v, '0')"/>
   <xsl:text>%</xsl:text>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempHourly">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(air/temp) and boolean(dewpoint/temp)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:if test="boolean(air/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-temp']"/>
    <xsl:with-param name="rows" select="$rows"/>
    <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="temp" select="air"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(dewpoint/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='tempHourly-dew']"/>
    <xsl:with-param name="temp" select="dewpoint"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tempAt|SST|OAT|tempMaxFQ|tempCity">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o=name($this)]"/>
   <xsl:with-param name="rows" select="1"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tempMaxAt|tempMinAt|tempMaxPeriod|tempMinPeriod|tempMaxDaytime|tempMinNighttime|tempCityMax|tempCityMin|waterTemp">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="period">
   <xsl:choose>
    <xsl:when test="boolean(period)">
     <xsl:value-of select="$trans/durationSince[@o=$this/period/@v]"/>
    </xsl:when>
    <xsl:when test="boolean(periodNotAvailable) and boolean(temp)">
     <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
    </xsl:when>
    <xsl:otherwise></xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o=name($this)], '|'), $period, substring-after($trans/hdr[@o=name($this)], '|'))"/>
   <xsl:with-param name="rows" select="1"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tempMinGround">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o=name($this)], '|'), $trans/durationSince[@o=$this/period/@v], substring-after($trans/hdr[@o=name($this)], '|'))"/>
   <xsl:with-param name="rows" select="1"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="temp24h">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(tempMinPeriod/temp)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o='tempMaxPeriod'], '|'), $trans/durationSince[@o=$this/tempMaxPeriod/period/@v], substring-after($trans/hdr[@o='tempMaxPeriod'], '|'))"/>
   <xsl:with-param name="rows" select="$rows"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="tempMaxPeriod"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(tempMinPeriod/temp)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="concat(substring-before($trans/hdr[@o='tempMinPeriod'], '|'), $trans/durationSince[@o=$this/tempMinPeriod/period/@v], substring-after($trans/hdr[@o='tempMinPeriod'], '|'))"/>
    <xsl:with-param name="temp" select="tempMinPeriod"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="printTemp">
  <xsl:param name="hdr"/>
  <xsl:param name="notavail"/>
  <xsl:param name="rows"/>
  <xsl:param name="s"/>
  <xsl:param name="temp"/>
  <xsl:param name="trans"/>
  <xsl:if test="$method = 'html' and $s != ''">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="$s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$hdr"/>
  </td>
  <xsl:choose>
   <xsl:when test="boolean($temp/notAvailable)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/temp/@u = 'C'">
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(($temp/temp/@v - 32) div 1.8, '0.0')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text> °C</xsl:text>
    <xsl:if test="boolean($temp/hour)">
     <xsl:value-of select="concat(substring-before($trans/t[@o='time-at'], '|'), $temp/hour/@v, ':00 UTC', substring-after($trans/t[@o='time-at'], '|'))"/>
    </xsl:if>
    </td>
    <xsl:choose>
     <xsl:when test="boolean($temp/hour)">
      <xsl:text>&#9;&#9;&#9;</xsl:text>
     </xsl:when>
     <xsl:otherwise>
      <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     </xsl:otherwise>
    </xsl:choose>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="$temp/temp/@u = 'C'">
      <!--xsl:value-of select="format-number($temp/temp/@v * 1.8 + 32, '0.#')"/-->
      <xsl:value-of select="format-number(floor(10 * ($temp/temp/@v * 1.8 + 32 + 0.05)) div 10, '0.0')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$temp/temp/@v"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:text> °F</xsl:text>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="QNH|stationPressure|somePressure|SLPhPa|SLPinHg|regQNH|QFE|QFF">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(hPa) and boolean(inHg)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </xsl:element>
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </td>
   </xsl:when>
   <xsl:when test="boolean(invalidFormat)">
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="boolean(hPa)">
      <xsl:value-of select="hPa/@v"/>
     </xsl:when>
     <xsl:when test="boolean(mmHg)">
      <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000) * $INHG2HPA, '0')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$trans/units[@o='hPa']"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="boolean(hPa) and boolean(inHg)">
      <xsl:value-of select="format-number(hPa/@v div $INHG2HPA, '0.00')"/>
     </xsl:when>
     <xsl:when test="boolean(inHg)">
      <xsl:value-of select="inHg/@v"/>
     </xsl:when>
     <xsl:when test="boolean(hPa)">
      <xsl:value-of select="format-number(hPa/@v div $INHG2HPA, '0.00')"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="format-number(mmHg/@v div ($FT2M div 12 * 1000), '0.00')"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="$trans/units[@o='inHg']"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(hPa) and boolean(inHg)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="format-number(inHg/@v * $INHG2HPA, '0')"/>
   <xsl:value-of select="$trans/units[@o='hPa']"/>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="inHg/@v"/>
   <xsl:value-of select="$trans/units[@o='inHg']"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="cloudMaxCover">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='cloudMaxCover']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(SKC)">
    <xsl:value-of select="$trans/cloudCover[@o='SKC']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudAbove">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="boolean(isThin)">
    <xsl:value-of select="$trans/hdr[@o='cloudLayerThin']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='cloudLayer']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <xsl:call-template name="printCloud">
   <xsl:with-param name="at_abv" select="'cloud-above'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudCoverVar">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloudCoverVar']"/></td>
  <xsl:choose>
   <xsl:when test="boolean(cloudBase)">
    <xsl:call-template name="printCloud">
     <xsl:with-param name="at_abv" select="'cloud-at'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:otherwise>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='cloudCoverVar2']"/></td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover2/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="reportConcerns">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='reportConcerns']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:variable name="chg" select="$trans/concernsChange[@o=$this/change/@v]"/>
  <xsl:value-of select="concat(substring-before($chg, '|'), $trans/concernsSubject[@o=$this/subject/@v], substring-after($chg, '|'))"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudOpacityLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='cloudOpacityLvl']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat(oktas/@v, '/8')"/>
  <xsl:if test="boolean(weather)">
   <xsl:text> </xsl:text>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="this" select="weather"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(cloudType)">
   <xsl:value-of select="concat(' ', $trans/cloudType[@o=$this/cloudType/@v])"/>
  </xsl:if>
  <xsl:value-of select="concat(' ', $trans/t[@o='cloud-at'], ' ')"/>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  <xsl:text>&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="RH">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='relHumid']"/></td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="relHumid/@v"/>
  <xsl:text>%</xsl:text>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="AI">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='AI']"/></td>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="AIVal/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rwyState">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(SNOCLO)">
    <td nowrap="1" colspan="3">
    <xsl:value-of select="$trans/t[@o='SNOCLO']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:value-of select="substring-before($trans/hdr[@o='stateOfRwy'], '|')"/>
    <xsl:choose>
     <xsl:when test="boolean(rwyDesigAll)">
      <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
     </xsl:when>
     <xsl:when test="boolean(rwyDesigRep)">
      <xsl:value-of select="$trans/t[@o='rwyDesigRep']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:value-of select="substring-after($trans/hdr[@o='stateOfRwy'], '|')"/>
    </td>
    <td colspan="2">
    <xsl:choose>
     <xsl:when test="boolean(depositType/notAvailable) and boolean(depositExtent/notAvailable) and boolean(depositDepth/notAvailable) and boolean(friction/notAvailable)">
      <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </xsl:when>

     <xsl:otherwise>

      <xsl:if test="boolean(cleared)">
       <xsl:value-of select="$trans/t[@o='cleared']"/>
      </xsl:if>

      <xsl:variable name="delim1">
       <xsl:if test="boolean(cleared)">, </xsl:if>
      </xsl:variable>
      <xsl:if test="boolean(depositType/depositTypeVal)">
       <xsl:value-of select="$delim1"/>
       <xsl:value-of select="$trans/depositType[@o=$this/depositType/depositTypeVal/@v]"/>
      </xsl:if>

      <xsl:variable name="delim2">
       <xsl:if test="$delim1 != '' or boolean(depositType/depositTypeVal)">, </xsl:if>
      </xsl:variable>
      <xsl:if test="boolean(depositExtent/invalidFormat)">
       <xsl:value-of select="$delim2"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>: '</xsl:text>
       <xsl:value-of select="depositExtent/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="boolean(depositExtent/depositExtentVal)">
       <xsl:value-of select="$delim2"/>
       <xsl:value-of select="substring-before($trans/depositExtent[@o=$this/depositExtent/depositExtentVal/@v], '|')"/>
       <xsl:value-of select="$trans/t[@o='depositExtent']"/>
       <xsl:value-of select="substring-after($trans/depositExtent[@o=$this/depositExtent/depositExtentVal/@v], '|')"/>
      </xsl:if>

      <xsl:variable name="delim3">
       <xsl:if test="$delim2 != '' or boolean(depositExtent/invalidFormat) or boolean(depositExtent/depositExtentVal)">, </xsl:if>
      </xsl:variable>
      <xsl:if test="boolean(depositDepth/invalidFormat)">
       <xsl:value-of select="$delim3"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>: '</xsl:text>
       <xsl:value-of select="depositDepth/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="boolean(depositDepth/depositDepthVal)">
       <xsl:value-of select="$delim3"/>
       <xsl:if test="depositDepth/depositDepthVal/@v &lt; 99">
        <xsl:value-of select="substring-before($trans/t[@o='depositDepth'], '|')"/>
       </xsl:if>
       <xsl:choose>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 1">
         <xsl:value-of select="concat('&lt;1', $trans/units[@o='MM'])"/>
        </xsl:when>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 91">
         <xsl:value-of select="concat(depositDepth/depositDepthVal/@v, $trans/units[@o='MM'])"/>
        </xsl:when>
        <xsl:when test="depositDepth/depositDepthVal/@v &lt; 99">
         <xsl:value-of select="concat(50 * (depositDepth/depositDepthVal/@v - 90), $trans/units[@o='MM'])"/>
        </xsl:when>
        <xsl:otherwise>
         <xsl:value-of select="$trans/t[@o='rwyNotInUse']"/>
        </xsl:otherwise>
       </xsl:choose>
       <xsl:value-of select="substring-after($trans/t[@o='depositDepth'], '|')"/>
      </xsl:if>
      <xsl:variable name="delim4">
       <xsl:if test="$delim3 != '' or boolean(depositDepth/invalidFormat) or boolean(depositDepth/depositDepthVal)">, </xsl:if>
      </xsl:variable>
      <xsl:if test="boolean(friction/invalidFormat)">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
       <xsl:text>: '</xsl:text>
       <xsl:value-of select="friction/invalidFormat/@v"/>
       <xsl:text>')</xsl:text>
      </xsl:if>
      <xsl:if test="boolean(friction/coefficient)">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="concat($trans/t[@o='friction'], format-number(friction/coefficient/@v div 100, '0.00'))"/>
      </xsl:if>
      <xsl:if test="boolean(friction/brakingAction)">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="$trans/friction[@o=$this/friction/brakingAction/@v]"/>
      </xsl:if>
      <xsl:if test="boolean(friction/unreliable)">
       <xsl:value-of select="$delim4"/>
       <xsl:value-of select="$trans/friction[@o='99']"/>
      </xsl:if>
     </xsl:otherwise>
    </xsl:choose>
    </td>
    </xsl:otherwise>
   </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windShear">
  <xsl:param name="trans"/>
  <tr>
   <xsl:if test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='windShearRwy'], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(rwyDesigAll)">
    <xsl:value-of select="$trans/t[@o='rwyDesigAll']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='windShearRwy'], '|')"/>
  </td>
  <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='windShear']"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="colourCode">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(BLACK) and boolean(currentColour) and boolean(predictedColour)">3</xsl:when>
    <xsl:when test="boolean(BLACK) and boolean(currentColour)">2</xsl:when>
    <xsl:when test="boolean(currentColour) and boolean(predictedColour)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o='colourCode']"/>
  </xsl:element>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(BLACK)">
    <xsl:value-of select="$trans/colour[@o='BLACK']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/colour[@o=$this/currentColour/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(currentColour) and boolean(BLACK)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/colour[@o=$this/currentColour/@v]"/>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(predictedColour)">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <xsl:value-of select="$trans/t[@o='predictedColour']"/>
   <br /><xsl:text>&#10;&#9;&#9;&#9;</xsl:text>
   <xsl:choose>
    <xsl:when test="currentColour/@v != predictedColour/@v">
     <xsl:value-of select="$trans/colour[@o=$this/predictedColour/@v]"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/colour[@o='noChange']"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="windShearLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" rowspan="2">
  <xsl:value-of select="$trans/hdr[@o='windShearLvl']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='topOfLayer'], ' ', level/@v * 100, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(level/@v * 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <xsl:variable name="dir">
   <xsl:value-of select="concat($trans/t[@o='wind-from'], ' ')"/>
   <xsl:value-of select="$trans/compassDir16/arr[position()=1+format-number($this/wind/dir/@v div 45 * 2, '0')]"/>
   <xsl:value-of select="concat(' (', wind/dir/@v, '°)')"/>
  </xsl:variable>
  <xsl:call-template name="printSpeed">
   <xsl:with-param name="dir" select="$dir"/>
   <xsl:with-param name="speed" select="wind/speed"/>
   <xsl:with-param name="delim" select="'&#9;&#9;'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="printLayerHeight">
  <xsl:param name="height"/>
  <xsl:param name="trans"/>
  <xsl:value-of select="concat($height, $trans/units[@o='M'], ' (', format-number($height div $FT2M div 100, '#0'), '00', $trans/units[@o='FT'], ') AGL')"/>
 </xsl:template>

 <xsl:template match="turbulence|icing">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/turbulenceDescr[@o=$this/turbulenceDescr/@v]"/>
  <xsl:value-of select="$trans/icingDescr[@o=$this/icingDescr/@v]"/>
  <xsl:value-of select="concat(', ', $trans/t[@o='level-from'], ' ')"/>
  <xsl:choose>
   <!-- WMO-No. 306 Vol I.1, Part A, coding table 1690 -->
   <xsl:when test="layerBase/@v = 0">
    <xsl:value-of select="concat('&lt;30', $trans/units[@o='M'], ' (&lt;100', $trans/units[@o='FT'], ') AGL')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="boolean(layerTop)">
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerTop/@v * 30"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="layerThickness/@v = 0">
    <xsl:value-of select="$trans/t[@o='toTopOfCloud']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(' ', $trans/t[@o='level-to'], ' ')"/>
    <!-- WMO-No. 306 Vol I.1, Part A, coding table 0300 -->
    <xsl:call-template name="printLayerHeight">
     <xsl:with-param name="height" select="layerBase/@v * 30 + layerThickness/@v * 300"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="amendment">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="concat($trans/t[@o='amendment'], ' ')"/>
  <xsl:choose>
   <xsl:when test="boolean(isNotScheduled)">
    <xsl:value-of select="$trans/t[@o='isNotScheduled']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='isLtdToCldVisWind']"/>
    <xsl:if test="boolean(hourFrom)">
     <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-from'], '|'), hourFrom/@v, ':00 UTC', substring-after($trans/t[@o='time-from'], '|'))"/>
    </xsl:if>
    <xsl:if test="boolean(hourTill)">
     <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-till'], '|'), hourTill/@v, ':00 UTC', substring-after($trans/t[@o='time-till'], '|'))"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="limMetwatch|autoMetwatch">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  <xsl:if test="boolean(timeFrom)">
   <xsl:text> </xsl:text>
   <xsl:value-of select="substring-before($trans/t[@o='time-from'], '|')"/>
   <xsl:value-of select="format-number(timeFrom/day/@v, '0')"/>
   <xsl:value-of select="concat('., ', timeFrom/hour/@v, ':00 UTC')"/>
   <xsl:value-of select="substring-after($trans/t[@o='time-from'], '|')"/>
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-till'], '|'))"/>
   <xsl:value-of select="format-number(timeTill/day/@v, '0')"/>
   <xsl:value-of select="concat('., ', timeTill/hour/@v, ':00 UTC')"/>
   <xsl:value-of select="substring-after($trans/t[@o='time-till'], '|')"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <!-- combine all trend nodes into one set and process them in one go -->
 <xsl:template match="trend">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="../trend" mode="go">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="trend" mode="go">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() = 1">
   <xsl:text>&#10;</xsl:text>
   <tr>
   <td></td>
   <td nowrap="1" colspan="3"><b>
    <xsl:if test="name(..) = 'metar'">
     <xsl:value-of select="$trans/hdr[@o='trend']"/>
    </xsl:if>
    <xsl:if test="name(..) != 'metar'">
     <xsl:value-of select="$trans/hdr[@o='trendTAF']"/>
    </xsl:if>
    <xsl:if test="$method != 'html'">
     <xsl:if test="name(..) = 'metar'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trend_ul'])"/>
     </xsl:if>
     <xsl:if test="name(..) != 'metar'">
      <xsl:value-of select="concat('&#10;', $trans/hdr[@o='trendTAF_ul'])"/>
     </xsl:if>
    </xsl:if>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <tr>
  <xsl:choose>
   <xsl:when test="$method = 'html'">
    <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
   </xsl:when>
   <xsl:when test="position() != 1">
   <xsl:text>&#10;</xsl:text>
   </xsl:when>
  </xsl:choose>
  <td nowrap="1" colspan="3">
  <xsl:choose>
   <xsl:when test="trendType/@v = 'NOSIG'">
    <xsl:value-of select="$trans/t[@o='NOSIG']"/>
   </xsl:when>
   <xsl:otherwise>
    <b>
    <xsl:if test="boolean(probability)">
     <xsl:value-of select="concat(substring-before($trans/t[@o='prob'], '|'), probability/@v, substring-after($trans/t[@o='prob'], '|'))"/>
    </xsl:if>
    <xsl:if test="boolean(trendTime1)">
     <xsl:if test="boolean(probability)"><xsl:text> </xsl:text></xsl:if>
     <xsl:variable name="timeSpec">
      <xsl:choose>
       <xsl:when test="trendTime1/timeSpec/@v = 'AT'">
        <xsl:value-of select="$trans/t[@o='time-at']"/>
       </xsl:when>
       <xsl:when test="trendTime1/timeSpec/@v = 'FM'">
        <xsl:value-of select="$trans/t[@o='time-from']"/>
       </xsl:when>
       <xsl:otherwise>
        <xsl:value-of select="$trans/t[@o='time-till']"/>
       </xsl:otherwise>
      </xsl:choose>
     </xsl:variable>
     <xsl:value-of select="substring-before($timeSpec, '|')"/>
     <xsl:if test="boolean(trendTime1/day)">
      <xsl:value-of select="concat(format-number(trendTime1/day/@v, '0'), '., ')"/>
     </xsl:if>
     <xsl:value-of select="concat(trendTime1/hour/@v, ':', trendTime1/minute/@v, ' UTC', substring-after($timeSpec, '|'))"/>
     <xsl:if test="boolean(trendTime2)">
      <xsl:value-of select="concat(' ', substring-before($trans/t[@o='time-till'], '|'))"/>
      <xsl:if test="boolean(trendTime2/day)">
       <xsl:value-of select="concat(format-number(trendTime2/day/@v, '0'), '., ')"/>
      </xsl:if>
      <xsl:value-of select="concat(trendTime2/hour/@v, ':', trendTime2/minute/@v, ' UTC', substring-after($trans/t[@o='time-till'], '|'))"/>
      <xsl:if test="not(boolean(trendTime1/day)) and trendTime1/hour/@v &gt;= trendTime2/hour/@v">
       <xsl:value-of select="$trans/t[@o='nextDay']"/>
      </xsl:if>
     </xsl:if>
    </xsl:if>
    <xsl:if test="$trans/t[@o=$this/trendType/@v] != ':' and (boolean(probability) or boolean(trendTime1))">
     <xsl:text> </xsl:text>
    </xsl:if>
    <xsl:value-of select="$trans/t[@o=$this/trendType/@v]"/>
    </b>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="sfcWind|CAVOK|visPrev|visVert|weather[position()=1]|cloud[position()=1]|rwyState|colourCode|turbulence|icing|windShearLvl|QNH|obscuration">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <!-- combine all tafRemark nodes into one set and process them in one go -->
 <xsl:template match="tafRemark">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="../tafRemark" mode="go">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="tafRemark" mode="go">
  <xsl:param name="trans"/>
  <xsl:if test="position() = 1">
   <xsl:text>&#10;</xsl:text>
   <tr>
   <xsl:if test="$method = 'html'">
    <td><b>RMK</b></td>
   </xsl:if>
   <td nowrap="1" colspan="3"><b>
    <xsl:value-of select="$trans/hdr[@o='remark']"/>
    <xsl:if test="$method != 'html'">
     <xsl:value-of select="concat('&#10;', $trans/hdr[@o='remark_ul'])"/>
    </xsl:if>
   </b></td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="*">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <!-- combine all remark nodes into one set and process them in one go -->
 <xsl:template match="remark">
  <xsl:param name="trans"/>
  <xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:if test="$method = 'html'">
   <td><b>RMK</b></td>
  </xsl:if>
  <td nowrap="1" colspan="3"><b>
   <xsl:value-of select="$trans/hdr[@o='remark']"/>
   <xsl:if test="$method != 'html'">
    <xsl:value-of select="concat('&#10;', $trans/hdr[@o='remark_ul'])"/>
   </xsl:if>
  </b></td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="../remark" mode="go">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="remark" mode="go">
  <xsl:param name="trans"/>
  <xsl:variable name="rmk" select="name(child::*[last()])"/>
  <xsl:choose>
   <xsl:when test="$rmk = 'cloud'">
    <xsl:apply-templates select="cloud">
     <xsl:with-param name="trans" select="$trans"/>
     <xsl:with-param name="s_list" select="cloud/@s"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="$rmk = 'visRwy'">
    <xsl:apply-templates select="visRwy">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="child::*[last()]">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="ERROR">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <td nowrap="1" colspan="4">
  <pre style="margin: 0; font-size: 90%;">
  <xsl:value-of select="concat($trans/hdr[@o='ERROR'], $trans/error[@o=$this/@errorType], ': ', @s)"/>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="warning">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <td nowrap="1" colspan="4">
  <pre style="margin: 0; font-size: 90%;">
  <xsl:value-of select="$trans/hdr[@o='warning']"/>
  <xsl:choose>
   <xsl:when test="@s != ''">
    <xsl:value-of select="concat(substring-before($trans/warning[@o=$this/@warningType], '|'), @s, substring-after($trans/warning[@o=$this/@warningType], '|'))"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/warning[@o=$this/@warningType]"/>
   </xsl:otherwise>
  </xsl:choose>
  </pre>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="invalidFormat">
  <xsl:param name="trans"/>
  <xsl:value-of select="concat('(', $trans/t[@o='invalidFormat'])"/>
  <xsl:text>: '</xsl:text>
  <xsl:value-of select="@v"/>
  <xsl:text>')</xsl:text>
 </xsl:template>

 <xsl:template match="CAVOK|RVRNO|needMaint|fcstAutoMETAR|fcstCancelled">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b>
   <xsl:choose>
    <xsl:when test="boolean(@s)">
     <xsl:value-of select="@s"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="name(.)"/>
    </xsl:otherwise>
   </xsl:choose>
   </b></td>
  </xsl:if>
  <td colspan="3">
   <xsl:value-of select="$trans/t[@o=name($this)]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="keyword">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td colspan="3">
  <xsl:choose>
   <xsl:when test="$trans/t[@o=$this/@v] != ''">
    <xsl:value-of select="$trans/t[@o=$this/@v]"/>
    <xsl:if test="@v = 'EPO' or @v = 'EPC' or @v = 'EPM'">
     <!-- Sheep Mountain Airport -->
     <xsl:if test="../../obsStationId/id/@v = 'PASP'"> (Tahetna pass)</xsl:if>
     <!-- Cantwell -->
     <xsl:if test="../../obsStationId/id/@v = 'PATW'"></xsl:if>
     <!-- Merrill Pass West -->
     <xsl:if test="../../obsStationId/id/@v = 'PAER'"></xsl:if>
     <!-- Farewell Lake Seaplane Base -->
     <xsl:if test="../../obsStationId/id/@v = 'PAFK'"></xsl:if>
     <!-- Healy River Airport -->
     <xsl:if test="../../obsStationId/id/@v = 'PAHV'"></xsl:if>
     <!-- Port Alsworth -->
     <xsl:if test="../../obsStationId/id/@v = 'PALJ'"></xsl:if>
     <!-- Big River Lake -->
     <xsl:if test="../../obsStationId/id/@v = 'PALV'"></xsl:if>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="@s"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsStationType">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/stationType[@o=$this/stationType/@v]"/>
  </td></tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visListAtLoc">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="visLocData">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="visLocData">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="position() = 1">
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="rowspan"><xsl:value-of select="last()"/></xsl:attribute>
     <b><xsl:value-of select="../@s"/></b>
    </xsl:element>
   </xsl:if>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='visLoc'], '|')"/>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirTo'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:value-of select="substring-after($trans/hdr[@o='visLoc'], '|')"/>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibility"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="MOV|MOVD">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:value-of select="$trans/t[@o=name($this)]"/>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirTo'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="locationAnd">
  <xsl:param name="locOrDir"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:value-of select="$trans/t[@o=name($this)]"/>
  <xsl:apply-templates select="locationThru">
   <xsl:with-param name="locOrDir" select="$locOrDir"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(isStationary)">
   <xsl:if test="not(name(..) = 'MOV' or name(..) = 'MOVD')">
    <xsl:text>,</xsl:text>
   </xsl:if>
   <xsl:value-of select="$trans/t[@o='isStationary']"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="locationThru">
  <xsl:param name="locOrDir"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="position() != 1">
     <xsl:text>,</xsl:text>
     <xsl:apply-templates select="location">
      <xsl:with-param name="locOrDirBefore"/>
      <xsl:with-param name="locOrDirAfter"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="location">
     <xsl:with-param name="locOrDirBefore" select="substring-before($trans/t[@o=$locOrDir], '|')"/>
     <xsl:with-param name="locOrDirAfter" select="substring-after($trans/t[@o=$locOrDir], '|')"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="location">
  <xsl:param name="locOrDirBefore"/>
  <xsl:param name="locOrDirAfter"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() != 1">
   <xsl:value-of select="substring-before($trans/t[@o='compassDirThrough'], '|')"/>
  </xsl:if>
  <xsl:if test="boolean(inDistance)">
   <xsl:value-of select="$trans/t[@o='inDistance']"/>
  </xsl:if>
  <xsl:if test="boolean(inVicinity)">
   <xsl:value-of select="$trans/t[@o='inVicinity']"/>
  </xsl:if>
  <xsl:if test="boolean(distance)">
   <xsl:value-of select="concat(' ', distance/@v, $trans/units[@o=$this/distance/@u])"/>
  </xsl:if>
  <xsl:if test="position() = 1 and not(boolean(locationSpec))">
   <xsl:value-of select="$locOrDirBefore"/>
  </xsl:if>
  <xsl:if test="boolean(locationSpec)">
   <xsl:value-of select="concat(' ', $trans/locationSpec[@o=$this/locationSpec/@v])"/>
  </xsl:if>
  <xsl:if test="boolean(obscgMtns)">
   <xsl:value-of select="$trans/t[@o='obscgMtns']"/>
  </xsl:if>
  <xsl:if test="position() = 1 and boolean(isGrid)">
   <xsl:value-of select="$trans/t[@o='isGrid']"/>
  </xsl:if>
  <xsl:if test="boolean(quadrant)">
   <xsl:text> </xsl:text>
   <xsl:for-each select="quadrant">
    <xsl:variable name="this2" select="."/>
    <xsl:if test="position() != 1">
     <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
    </xsl:if>
    <xsl:value-of select="$trans/quadrant[@o=$this2/@v]"/>
   </xsl:for-each>
   <xsl:value-of select="concat(' ', $trans/t[@o='quadrant'])"/>
  </xsl:if>
  <xsl:if test="boolean(compassDir)">
   <xsl:variable name="quad">
    <xsl:choose>
     <xsl:when test="boolean(isQuadrant)">Quad</xsl:when>
     <xsl:otherwise/>
    </xsl:choose>
   </xsl:variable>
   <xsl:variable name="ccd" select="$trans/t[@o=concat('compassDirDescr', $quad)]"/>
   <xsl:value-of select="substring-before($ccd, '|')"/>
   <xsl:value-of select="$trans/compassDir[@o=$this/compassDir/@v]"/>
   <xsl:value-of select="substring-after($ccd, '|')"/>
  </xsl:if>
  <xsl:if test="position() = 1 and not(boolean(locationSpec))">
   <xsl:value-of select="$locOrDirAfter"/>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:value-of select="substring-after($trans/t[@o='compassDirThrough'], '|')"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="visibilityAtLoc">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:if test="boolean(locationAt)">
   <xsl:value-of select="$trans/visibilityAtLoc[@o=$this/locationAt/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(rwyDesig)">
   <xsl:value-of select="$trans/t[@o='visibilityAt']"/>
   <xsl:if test="boolean(isApproach)">
    <xsl:value-of select="concat(' ', $trans/t[@o='approach'])"/>
   </xsl:if>
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
   <xsl:text>:&#9;</xsl:text>
  </xsl:if>
  </td>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibility"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visMin">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='rmkVisMin']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="visVar2">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="../visVar1/@s"/>
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='rmkVisVar']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="../visVar1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='to']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="correctedAt|amendedAt">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="concat(format-number(hour/@v, '00'), ':', format-number(minute/@v, '00'), ' UTC')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="precipHourly|precipCity">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o=name($this)], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(timeBeforeObsSince)">
    <xsl:text> </xsl:text>
    <xsl:apply-templates select="timeBeforeObsSince">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="boolean(periodNotAvailable)">
    <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(period3o6h)">
    <xsl:value-of select="$trans/t[@o='precip3o6Hour']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/durationSince[@o=$this/period/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='precipHourly'], '|')"/>
  </td>
  <xsl:call-template name="precipAmountVal">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template name="precipAmountVal">
  <xsl:param name="trans"/>
  <xsl:variable name="txt" select="name(notAvailable|invalidFormat|coverNotCont|noMeasurement|traces)"/>
  <xsl:choose>
   <xsl:when test="$txt = ''">
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="precipAmount"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:choose>
     <xsl:when test="precipAmount/@u = 'IN' and precipAmount/@v &lt; 1">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'MM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:when test="precipAmount/@u = 'IN'">
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'CM'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:when>
     <xsl:otherwise>
      <xsl:call-template name="unitConverter">
       <xsl:with-param name="val" select="precipAmount"/>
       <xsl:with-param name="unit" select="'IN'"/>
       <xsl:with-param name="factor" select="1"/>
       <xsl:with-param name="format" select="'0.#'"/>
       <xsl:with-param name="trans" select="$trans"/>
      </xsl:call-template>
     </xsl:otherwise>
    </xsl:choose>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o=$txt]"/>
    </td>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="snowIncr">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='snowIncr']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrPastHour'],'|')"/>
  <xsl:value-of select="pastHour/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrPastHour'], '|')"/>
  <xsl:text>, </xsl:text>
  <xsl:value-of select="substring-before($trans/t[@o='snowIncrOnGround'],'|')"/>
  <xsl:value-of select="onGround/@v"/>
  <xsl:value-of select="substring-after($trans/t[@o='snowIncrOnGround'], '|')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypes">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(notAvailable)">1</xsl:when>
    <xsl:when test="boolean(skyObscured)">1</xsl:when>
    <xsl:when test="boolean(invalidFormat)">1</xsl:when>
    <xsl:when test="boolean(cloudTypeLowNA) and boolean(cloudTypeMiddleNA) and boolean(cloudTypeHighNA)">1</xsl:when>
    <xsl:otherwise>3</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o='cloudTypes']"/>
  </xsl:element>
  <td colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(invalidFormat)">
    <xsl:apply-templates select="invalidFormat">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="boolean(skyObscured)">
    <xsl:value-of select="$trans/t[@o='SKY_OBSC']"/>
   </xsl:when>
   <xsl:when test="boolean(cloudTypeLowNA) and boolean(cloudTypeMiddleNA) and boolean(cloudTypeHighNA)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    <xsl:if test="boolean(oktas)">
     <xsl:text> </xsl:text>
     <xsl:value-of select="concat(oktas/@v, '/8')"/>
     <xsl:if test="oktas/@v = 1">
      <xsl:value-of select="$trans/t[@o='lessOktas']"/>
     </xsl:if>
     <xsl:if test="oktas/@v = 7">
      <xsl:value-of select="$trans/t[@o='moreOktas']"/>
     </xsl:if>
    </xsl:if>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>&#10;&#9;</xsl:text><xsl:value-of select="$trans/t[@o='low']"/>
    <xsl:choose>
     <xsl:when test="boolean(cloudTypeLowNA)">
      <xsl:value-of select="$trans/t[@o='notAvailable']"/>
     </xsl:when>
     <xsl:when test="boolean(cloudTypeLowAboveOvercast)">
      <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:if test="boolean(oktasLow)">
       <xsl:value-of select="concat(oktasLow/@v, '/8')"/>
       <xsl:if test="oktasLow/@v = 1">
        <xsl:value-of select="$trans/t[@o='lessOktas']"/>
       </xsl:if>
       <xsl:if test="oktasLow/@v = 7">
        <xsl:value-of select="$trans/t[@o='moreOktas']"/>
       </xsl:if>
       <xsl:text> </xsl:text>
      </xsl:if>
      <xsl:value-of select="$trans/cloudTypeLow[@o=$this/cloudTypeLow/@v]"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 3">
   <tr>
   <xsl:text>&#9;</xsl:text>
   <td colspan="2">
   <xsl:value-of select="$trans/t[@o='middle']"/>
   <xsl:choose>
    <xsl:when test="boolean(cloudTypeMiddleNA)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(cloudTypeMiddleAboveOvercast)">
     <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:if test="boolean(oktasMiddle)">
      <xsl:value-of select="concat(oktasMiddle/@v, '/8')"/>
      <xsl:if test="oktasMiddle/@v = 1">
       <xsl:value-of select="$trans/t[@o='lessOktas']"/>
      </xsl:if>
      <xsl:if test="oktasMiddle/@v = 7">
       <xsl:value-of select="$trans/t[@o='moreOktas']"/>
      </xsl:if>
      <xsl:text> </xsl:text>
     </xsl:if>
     <xsl:value-of select="$trans/cloudTypeMiddle[@o=$this/cloudTypeMiddle/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
   <tr>
   <td colspan="2">
   <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='high']"/>
   <xsl:choose>
    <xsl:when test="boolean(cloudTypeHighNA)">
     <xsl:value-of select="$trans/t[@o='notAvailable']"/>
    </xsl:when>
    <xsl:when test="boolean(cloudTypeHighAboveOvercast)">
     <xsl:value-of select="$trans/t[@o='cloudLayerAboveOvercast']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/cloudTypeHigh[@o=$this/cloudTypeHigh/@v]"/>
    </xsl:otherwise>
   </xsl:choose>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="section3|section4|section5">
  <xsl:param name="trans"/>
  <xsl:call-template name="section">
   <xsl:with-param name="trans" select="$trans"/>
   <xsl:with-param name="s" select="@s"/>
    <xsl:with-param name="section_nr" select="substring(name(), 8)"/>
  </xsl:call-template>
  <xsl:apply-templates select="*">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="windShift">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o='windShift']"/>
  <xsl:call-template name="printTime">
   <xsl:with-param name="time"  select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:if test="boolean(FROPA)">
   <xsl:value-of select="concat(' ', $trans/t[@o='FROPA'])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weatherHist">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:apply-templates select="weatherBeginEnd" mode="count"/>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <xsl:element name="td">
   <xsl:attribute name="nowrap">1</xsl:attribute>
   <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
   <xsl:value-of select="$trans/hdr[@o='weather']"/>
  </xsl:element>
  <xsl:apply-templates select="weatherBeginEnd">
   <xsl:with-param name="is_first" select="1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </tr>
  <xsl:apply-templates select="weatherBeginEnd">
   <xsl:with-param name="is_first" select="0"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(MOV) or boolean(MOVD) or boolean(locationAnd)">
   <tr>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1" colspan="2">
   <xsl:if test="boolean(locationAnd)">
    <xsl:apply-templates select="locationAnd">
     <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    <xsl:if test="boolean(MOV) or boolean(MOVD)">
     <xsl:text>,</xsl:text>
    </xsl:if>
   </xsl:if>
   <xsl:apply-templates select="MOV|MOVD">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="weatherBeginEnd" mode="count">
  <xsl:if test="position() = last()">
   <xsl:choose>
    <xsl:when test="boolean(../MOV) or boolean(../MOVD) or boolean(../locationAnd)">
     <xsl:value-of select="last() + 1"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="last()"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:if>
 </xsl:template>

 <xsl:template match="weatherBeginEnd">
  <xsl:param name="is_first"/>
  <xsl:param name="trans"/>
  <xsl:if test="$is_first = 1 and position() = 1">
   <td nowrap="1" colspan="2">
   <dl style="margin: 0em;"><dt>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="this" select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:text>:</xsl:text></dt>
   <xsl:apply-templates select="beganAt|endedAt">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:text>&#10;</xsl:text>
   </dl></td>
  </xsl:if>
  <xsl:if test="$is_first = 0 and position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <tr>
   <td nowrap="1" colspan="2">
   <dl style="margin: 0em;"><dt>
   <xsl:call-template name="printWeather">
    <xsl:with-param name="this" select="."/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:text>:</xsl:text></dt>
   <xsl:apply-templates select="beganAt|endedAt">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:text>&#10;</xsl:text>
   </dl></td>
   </tr>
  </xsl:if>
 </xsl:template>

 <xsl:template match="beganAt|endedAt">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:text>&#10;&#9;&#9;&#9;&#9;</xsl:text><dd>
  <xsl:value-of select="$trans/t[@o=name($this)]"/>
  <xsl:call-template name="printTime">
   <xsl:with-param name="time"  select="."/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </dd>
 </xsl:template>

 <xsl:template match="cloudType">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() != 1">
   <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
  </xsl:if>
  <xsl:value-of select="$trans/cloudType[@o=$this/@v]"/>
 </xsl:template>

 <xsl:template match="lightningType">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() = 1">
   <xsl:value-of select="concat($trans/phenomenon[@o='LTG'], ' ')"/>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:value-of select="concat(' ', $trans/t[@o='loc-and'], ' ')"/>
  </xsl:if>
  <xsl:value-of select="$trans/lightningType[@o=$this/@v]"/>
 </xsl:template>

 <xsl:template match="phenomenonAtLoc|phenomenonOnly">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td colspan="3">
  <xsl:apply-templates select="phenomDescrPre">
   <xsl:with-param name="post" select="' '"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:choose>
   <xsl:when test="boolean(weather)">
    <xsl:call-template name="printWeather">
     <xsl:with-param name="this" select="weather"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:when>
   <xsl:when test="boolean(cloudType)">
    <xsl:apply-templates select="cloudType">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:when test="boolean(cloudCover)">
    <xsl:value-of select="$trans/cloudCover[@o=$this/cloudCover/@v]"/>
   </xsl:when>
   <xsl:when test="boolean(lightningType)">
    <xsl:apply-templates select="lightningType">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/phenomenon[@o=$this/otherPhenom/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:apply-templates select="phenomDescrPost">
   <xsl:with-param name="pre" select="' '"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:if test="boolean(phenomDescrPost)">
    <xsl:text>,</xsl:text>
   </xsl:if>
   <xsl:apply-templates select="locationAnd">
    <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
   <xsl:if test="boolean(MOV) or boolean(MOVD)">
    <xsl:text>,</xsl:text>
   </xsl:if>
  </xsl:if>
  <xsl:apply-templates select="MOV|MOVD">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(baseBelowStation)">
   <xsl:value-of select="$trans/t[@o='baseBelowStation']"/>
  </xsl:if>
  <xsl:if test="boolean(isAloft)">
   <xsl:value-of select="$trans/t[@o='isAloft']"/>
  </xsl:if>
  <xsl:if test="boolean(isAround)">
   <xsl:value-of select="$trans/t[@o='isAround']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeAsoctd) or boolean(cloudTypeEmbd)">
   <xsl:text>, </xsl:text>
   <xsl:apply-templates select="cloudTypeAsoctd|cloudTypeEmbd">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="phenomDescrPre|phenomDescrPost">
  <xsl:param name="pre"/>
  <xsl:param name="post"/>
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:if test="position() = 1"><xsl:value-of select="$pre"/></xsl:if>
  <xsl:if test="position() != 1">
   <xsl:text>, </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/t[@o=$this/@v]"/>
  <xsl:if test="position() = last()"><xsl:value-of select="$post"/></xsl:if>
 </xsl:template>

 <xsl:template match="conditionMountain">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="condMountainLoc">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="condMountainLoc">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows" select="last()"/>
  <tr>
  <xsl:if test="position() = 1">
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     <b><xsl:value-of select="../@s"/></b>
    </xsl:element>
   </xsl:if>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:value-of select="$trans/hdr[@o='conditionMountain']"/>
   </xsl:element>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
  </xsl:if>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/cloudMountain[@o=$this/cloudMountain/@v]"/>
  <xsl:if test="boolean(cloudEvol)">
   <xsl:value-of select="concat('. ', $trans/phenomenon[@o='CLDS'], ': ', $trans/cloudEvol[@o=$this/cloudEvol/@v])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="conditionValley">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="condValleyLoc">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="condValleyLoc">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows" select="last()"/>
  <tr>
  <xsl:if test="position() = 1">
   <xsl:if test="$method = 'html'">
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     <b><xsl:value-of select="../@s"/></b>
    </xsl:element>
   </xsl:if>
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <xsl:value-of select="$trans/hdr[@o='conditionValley']"/>
   </xsl:element>
  </xsl:if>
  <xsl:if test="position() != 1">
   <xsl:text>&#9;&#9;&#9;</xsl:text>
  </xsl:if>
  <td nowrap="1" colspan="2">
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>: </xsl:text>
  </xsl:if>
  <xsl:value-of select="$trans/cloudValley[@o=$this/cloudValley/@v]"/>
  <xsl:if test="boolean(cloudBelowEvol)">
   <xsl:value-of select="concat('. ', $trans/phenomenon[@o='CLDS'], ': ', $trans/cloudBelowEvol[@o=$this/cloudBelowEvol/@v])"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="ceilingAtLoc">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/t[@o='ceiling']"/>
  <xsl:if test="boolean(isApproach)">
   <xsl:value-of select="concat(' ', $trans/t[@o='approach'])"/>
  </xsl:if>
  <xsl:if test="boolean(rwyDesig)">
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
  </xsl:if>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  <xsl:text>:</xsl:text>
  </td>
  <xsl:text>&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ')"/>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="opacityPhenom">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:choose>
   <xsl:when test="boolean(cloudTypeAsoctd) or boolean(cloudTypeEmbd)">
    <xsl:apply-templates select="opacityCloud|opacityWeather">
     <xsl:with-param name="trans" select="$trans"/>
     <xsl:with-param name="add_rows" select="1"/>
    </xsl:apply-templates>
    <tr>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <td nowrap="1" colspan="2">
    <xsl:apply-templates select="cloudTypeAsoctd|cloudTypeEmbd">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="opacityCloud|opacityWeather">
     <xsl:with-param name="trans" select="$trans"/>
     <xsl:with-param name="add_rows" select="0"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="cloudTypeAsoctd|cloudTypeEmbd">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:value-of select="concat(substring-before($trans/t[@o=name($this)], '|'), $trans/cloudType[@o=$this/@v], substring-after($trans/t[@o=name($this)], '|'))"/>
 </xsl:template>

 <xsl:template match="opacityCloud|opacityWeather">
  <xsl:param name="trans"/>
  <xsl:param name="add_rows"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows" select="last() + $add_rows"/>
  <tr>
  <xsl:choose>
   <xsl:when test="position() = 1">
    <xsl:if test="$method = 'html'">
     <xsl:element name="td">
      <xsl:attribute name="nowrap">1</xsl:attribute>
      <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
      <b><xsl:value-of select="../@s"/></b>
     </xsl:element>
    </xsl:if>
    <xsl:element name="td">
     <xsl:attribute name="nowrap">1</xsl:attribute>
     <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
     <xsl:value-of select="$trans/hdr[@o='cloudOpacityLvl']"/>
    </xsl:element>
   </xsl:when>
   <xsl:otherwise>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
  <td nowrap="1" colspan="2">
   <xsl:value-of select="concat(oktas/@v, '/8')"/>
   <xsl:if test="boolean(weather)">
    <xsl:text> </xsl:text>
    <xsl:call-template name="printWeather">
     <xsl:with-param name="this" select="weather"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
   </xsl:if>
   <xsl:if test="boolean(cloudType)">
    <xsl:value-of select="concat(' ', $trans/cloudType[@o=$this/cloudType/@v])"/>
   </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypeLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='cloud']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="$trans/cloudType[@o=$this/cloudType/@v]"/>
  <xsl:value-of select="concat(' ', $trans/t[@o='cloud-at'], ' ')"/>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudBase"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTrace">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='tracesOf']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(isLower)">
   <xsl:value-of select="concat($trans/t[@o='isLower'], ' ')"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeNotAvailable)">
   <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
  </xsl:if>
  <xsl:for-each select="cloudType">
   <xsl:variable name="this" select="."/>
   <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
   <xsl:value-of select="$trans/cloudType[@o=$this/@v]"/>
  </xsl:for-each>
  <xsl:apply-templates select="locationAnd">
   <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="seaCondition|swellCondition">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(notAvailable)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(seaCondVal)">
   <xsl:value-of select="$trans/seaCondition[@o=$this/seaCondVal/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(swellCondVal)">
   <xsl:value-of select="$trans/swellCondition[@o=$this/swellCondVal/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(locationAnd)">
   <xsl:text>,</xsl:text>
   <xsl:apply-templates select="locationAnd">
    <xsl:with-param name="locOrDir" select="'compassDirFrom'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obscuration">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='obscuration'], '|')"/>
  <xsl:if test="boolean(weather)">
   <xsl:call-template name="printWeather">
    <xsl:with-param name="this" select="weather"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(cloudPhenom)">
   <xsl:value-of select="$trans/cloudPhenom[@o=$this/cloudPhenom/@v]"/>
  </xsl:if>
  <xsl:value-of select="substring-after($trans/hdr[@o='obscuration'], '|')"/>
  </td>
  <xsl:for-each select="cloud">
   <xsl:call-template name="printCloud">
    <xsl:with-param name="at_abv" select="'cloud-at'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:for-each>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="variableCeiling">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" rowspan="2">
  <xsl:value-of select="$trans/hdr[@o='variableCeiling']"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='variable-from'], ' ', cloudBaseFrom/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(cloudBaseFrom/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat($trans/t[@o='variable-to'], ' ', cloudBaseTo/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(cloudBaseTo/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="pressureChange">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="concat(substring-before($trans/hdr[@o='pressureChange'], '|'), $trans/durationSince[@o=$this/period/@v], substring-after($trans/hdr[@o='pressureChange'], '|'))"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="sign">
     <xsl:if test="pressureChangeVal/@v &gt; 0">+</xsl:if>
    </xsl:variable>
    <xsl:value-of select="concat($sign, pressureChangeVal/@v, $trans/units[@o='hPa'])"/>
    <xsl:if test="boolean(pressureTendency)">
     <xsl:value-of select="concat(', ', $trans/pressureTend[@o=$this/pressureTendency/@v])"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="ceilVisVariable">
  <xsl:param name="trans"/>
  <tr>
  <xsl:call-template name="visibility_str">
   <xsl:with-param name="str" select="@s"/>
   <xsl:with-param name="rows" select="2"/>
  </xsl:call-template>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='ceilVisVariable']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibilityFrom"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="visibility_header">
   <xsl:with-param name="header" select="$trans/hdr[@o='to']"/>
   <xsl:with-param name="rows" select="1"/>
  </xsl:call-template>
  <xsl:call-template name="visibility">
   <xsl:with-param name="notavail" select="$trans/t[@o='notAvailable']"/>
   <xsl:with-param name="visVal" select="visibilityTo"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rwySfcCondition">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='rwySfcCondition']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:for-each select="*">
   <xsl:variable name="this" select="."/>
   <xsl:if test="name(.) = 'notAvailable'">
    <xsl:value-of select="$trans/t[@o='decelerometerReadingNA']"/>
   </xsl:if>
   <xsl:if test="name(.) = 'decelerometer'">
    <xsl:value-of select="concat($trans/t[@o='decelerometerReading'], ' ',@v)"/>
   </xsl:if>
   <xsl:if test="name(.) = 'rwySfc'">
    <xsl:value-of select="$trans/rwySfc[@o=$this/@v]"/>
   </xsl:if>
   <xsl:if test="position() != last()">
    <xsl:text>, </xsl:text>
   </xsl:if>
  </xsl:for-each>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="rainfall">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='rainfall']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(rainfall10min/@v, $trans/t[@o='rainfall10min'], rainfall0900/@v, $trans/t[@o='rainfall0900'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="NEFO_PLAYA">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='NEFO_PLAYA']"/>
  </td>
  <xsl:choose>
   <xsl:when test="boolean(SKC)">
    <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/cloudCover[@o='SKC']"/>
    </td>
   </xsl:when>
   <xsl:otherwise>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'FT'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td>
    <xsl:text>&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:call-template name="unitConverter">
     <xsl:with-param name="val" select="cloudBase"/>
     <xsl:with-param name="unit" select="'M'"/>
     <xsl:with-param name="factor" select="10"/>
     <xsl:with-param name="format" select="'0'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    </td>
   </xsl:otherwise>
  </xsl:choose>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="densityAlt|pressureAlt">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat(altitude/@v, $trans/units[@o='FT'])"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(altitude/@v div 10 * $FT2M, '0.0') * 10, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="VISNO|CHINO">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:variable name="s" select="$trans/t[@o=name($this)]"/>
  <xsl:variable name="p" select="$trans/t[@o='rwyDesig']"/>
  <xsl:value-of select="substring-before($s, '|')"/>
  <xsl:value-of select="substring-before($p, '|')"/>
  <xsl:value-of select="rwyDesig/@v"/>
  <xsl:value-of select="substring-after($p, '|')"/>
  <xsl:value-of select="substring-after($s, '|')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="obsTimeOffset">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='obsTimeOffset']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(minutes/@v, ' ', $trans/t[@o='minutes'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="nextFcstBy|nextFcstAt|amdAt">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(day/@v)">
   <xsl:value-of select="substring-before($trans/t[@o='onThe'], '|')"/>
   <xsl:value-of select="format-number(day/@v, '0')"/>
   <xsl:value-of select="substring-after($trans/t[@o='onThe'], '|')"/>
  </xsl:if>
  <xsl:value-of select="concat(hour/@v, ':', minute/@v, ' UTC')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="fcstAutoObs">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/hdr[@o='fcstAutoObs']"/>
  <xsl:if test="boolean(hourFrom/@v)">
   <xsl:value-of select="concat(' ', hourFrom/@v, ':00 - ', hourTill/@v, ':00 UTC')"/>
   <xsl:if test="hourFrom/@v &gt;= hourTill/@v">
    <xsl:value-of select="$trans/t[@o='nextDay']"/>
   </xsl:if>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="waterEquivOfSnow">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='waterEquivOfSnow'], '|')"/>
  <xsl:choose>
   <xsl:when test="boolean(period)">
    <xsl:value-of select="$trans/durationSince[@o=$this/period/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='onGround']"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="substring-after($trans/hdr[@o='waterEquivOfSnow'], '|')"/>
  </td>
  <xsl:call-template name="precipAmountVal">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="snowCover">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='snowCover']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/snowCoverType[@o=$this/snowCoverType/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="climate">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(precipAmount2Inch) or boolean(precipAmount2MM)">4</xsl:when>
    <xsl:when test="boolean(precipAmount1Inch) or boolean(precipAmount1MM) or boolean(traces)">3</xsl:when>
    <xsl:otherwise>2</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temp1']"/>
   <xsl:with-param name="rows" select="$rows"/>
   <xsl:with-param name="s" select="@s"/>
   <xsl:with-param name="temp" select="temp1"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temp2']"/>
   <xsl:with-param name="temp" select="temp2"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(precipAmount1Inch) or boolean(precipAmount1MM) or boolean(traces)">
   <tr>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='precipAmount1']"/>
   </td>
   <xsl:choose>
    <xsl:when test="boolean(precipAmount1Inch)">
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount1Inch/@v * ($FT2M div 12 * 1000), '0'), $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount1Inch/@v, $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:when test="boolean(precipAmount1MM)">
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount1MM/@v, $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount1MM/@v div ($FT2M div 12 * 1000), '0.00'), $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1" colspan="2">
     <xsl:value-of select="$trans/t[@o='traces']"/>
     </td>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(precipAmount2Inch) or boolean(precipAmount2MM)">
   <tr>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='precipAmount2']"/>
   </td>
   <xsl:choose>
    <xsl:when test="boolean(precipAmount2Inch)">
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount2Inch/@v * ($FT2M div 12 * 1000), '0'), $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount2Inch/@v, $trans/units[@o='IN'])"/>
     </td>
    </xsl:when>
    <xsl:otherwise>
     <td nowrap="1">
     <xsl:value-of select="concat(precipAmount2MM/@v, $trans/units[@o='MM'])"/>
     </td>
     <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
     <td nowrap="1">
     <xsl:value-of select="concat(format-number(precipAmount2MM/@v div ($FT2M div 12 * 1000), '0.00'), $trans/units[@o='IN'])"/>
     </td>
    </xsl:otherwise>
   </xsl:choose>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template match="tornadicActivity">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <dl style="margin: 0em;"><dt>
  <xsl:value-of select="$trans/tornadicActivity[@o=$this/tornadicActivityType/@v]"/>
   <xsl:if test="boolean(locationAnd)">
    <xsl:apply-templates select="locationAnd">
     <xsl:with-param name="locOrDir" select="'compassDirLocation'"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
    <xsl:if test="boolean(MOV) or boolean(MOVD)">
     <xsl:text>,</xsl:text>
    </xsl:if>
   </xsl:if>
   <xsl:apply-templates select="MOV|MOVD">
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:apply-templates>
  <xsl:text>:</xsl:text></dt>
  <xsl:apply-templates select="beganAt|endedAt">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
  </dl></td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="balloon">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:if test="boolean(disappearedAt)">
   <xsl:value-of select="substring-before($trans/t[@o='balloonDisapp'], '|')"/>
   <xsl:value-of select="concat(disappearedAt/distance/@v, $trans/units[@o=$this/disappearedAt/distance/@u])"/>
   <xsl:value-of select="substring-after($trans/t[@o='balloonDisapp'], '|')"/>
  </xsl:if>
  <xsl:if test="boolean(visibleTo)">
   <xsl:value-of select="substring-before($trans/t[@o='balloonVisib'], '|')"/>
   <xsl:value-of select="concat(visibleTo/distance/@v, $trans/units[@o=$this/visibleTo/distance/@u])"/>
   <xsl:value-of select="substring-after($trans/t[@o='balloonVisib'], '|')"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="firstObs|nextObs|lastObs">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="substring-before($trans/t[@o=name($this)], '|')"/>
  <xsl:if test="boolean(isManned)">
   <xsl:value-of select="$trans/t[@o='isManned']"/>
  </xsl:if>
  <xsl:if test="boolean(isStaffed)">
   <xsl:value-of select="$trans/t[@o='isStaffed']"/>
  </xsl:if>
  <xsl:value-of select="substring-after($trans/t[@o=name($this)], '|')"/>
  <xsl:if test="boolean(obsAt)">
   <xsl:value-of select="concat(' ', substring-before($trans/t[@o='onThe'], '|'))"/>
   <xsl:value-of select="format-number(obsAt/day/@v, '0')"/>
   <xsl:value-of select="substring-after($trans/t[@o='onThe'], '|')"/>
   <xsl:value-of select="concat(obsAt/hour/@v, ':', obsAt/minute/@v, ' UTC')"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="estimated">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:for-each select="estimatedItem">
   <xsl:variable name="this2" select="."/>
   <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
   <xsl:value-of select="$trans/estimatedItem[@o=$this2/@v]"/>
  </xsl:for-each>
  <xsl:value-of select="concat(' ', $trans/t[@o='estimated'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="RSNK|LAG_PK">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(wind/gustSpeed) and boolean(dewpoint)">5</xsl:when>
    <xsl:when test="boolean(wind/gustSpeed) or boolean(dewpoint)">4</xsl:when>
    <xsl:otherwise>3</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <b><xsl:value-of select="$trans/hdr[@o=name($this)]"/></b>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <xsl:call-template name="printTemp">
   <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-temp']"/>
   <xsl:with-param name="rows" select="1"/>
   <xsl:with-param name="temp" select="air"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(dewpoint)">
   <tr>
   <xsl:call-template name="printTemp">
    <xsl:with-param name="hdr" select="$trans/hdr[@o='temperature-dew']"/>
    <xsl:with-param name="rows" select="1"/>
    <xsl:with-param name="temp" select="dewpoint"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$trans/hdr[@o='sfcWind']"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="RADAT">
  <xsl:param name="trans"/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(isMissing)">2</xsl:when>
    <xsl:otherwise>3</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <b><xsl:value-of select="$trans/hdr[@o='RADAT']"/></b>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:choose>
   <xsl:when test="boolean(isMissing)">
    <tr>
    <td nowrap="1" colspan="3">
    <xsl:value-of select="$trans/t[@o='isMissing']"/>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:when>
   <xsl:otherwise>
    <tr>
    <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='relHumid']"/></td>
    <td nowrap="1" colspan="2">
    <xsl:value-of select="relHumid/@v"/>
    <xsl:text>%</xsl:text>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
    <tr>
    <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='freezingLvl']"/></td>
    <td nowrap="1">
    <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' ', distance/@v, $trans/units[@o='FT'])"/>
    </td>
    <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
    <td nowrap="1">
    <xsl:value-of select="concat(format-number(distance/@v div 10 * $FT2M, '0') * 10, $trans/units[@o='M'])"/>
    </td>
    </tr><xsl:text>&#10;</xsl:text>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="radiation">
  <xsl:param name="trans"/>
  <xsl:apply-templates select="radShortWave|radDirectSolar">
   <xsl:with-param name="trans" select="$trans"/>
   <xsl:with-param name="s" select="@s"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="radiationSun">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:apply-templates select="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave" mode="count" />
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="concat(substring-before($trans/hdr[@o='sunshine'], '|'), $trans/durationSince[@o=$this/sunshinePeriod/@v], substring-after($trans/hdr[@o='sunshine'], '|'))"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(sunshine)">
    <xsl:variable name="sunshineMinutes">
     <xsl:if test="sunshine/@u = 'min'">
      <xsl:value-of select="sunshine/@v" />
     </xsl:if>
     <xsl:if test="sunshine/@u = 'hour'">
      <xsl:value-of select="format-number(sunshine/@v * 60, '0')" />
     </xsl:if>
    </xsl:variable>
    <xsl:choose>
     <xsl:when test="$sunshineMinutes &gt; 59">
      <xsl:variable name="min" select="$sunshineMinutes mod 60"/>
      <xsl:value-of select="concat(($sunshineMinutes - $min) div 60, $trans/units[@o='H'])"/>
      <xsl:if test="$min &gt; 0">
       <xsl:value-of select="concat(' ', $min, $trans/units[@o='MIN'])"/>
      </xsl:if>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="concat($sunshineMinutes, $trans/units[@o='MIN'])"/>
     </xsl:otherwise>
    </xsl:choose>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="radiationSun/*" mode="count">
  <xsl:if test="position() = last()">
   <xsl:value-of select="last() + 1"/>
  </xsl:if>
 </xsl:template>

 <xsl:template match="rad0PosNet|rad1NegNet|rad2GlobalSolar|rad3DiffusedSolar|rad4DownwardLongWave|rad5UpwardLongWave|rad6ShortWave|radShortWave|radDirectSolar">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html' and @s != ''">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="concat(substring-before($trans/hdr[@o=name($this)], '|'), $trans/durationSince[@o=$this/../radiationPeriod/@v], substring-after($trans/hdr[@o=name($this)], '|'))"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat(radiationValue/@v, $trans/units[@o=$this/radiationValue/@u])"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="hailStones">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='hailStones']"/>
  </td>
  <td colspan="2">
  <xsl:value-of select="$trans/t[@o='hailStoneSize']"/>
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="hailStoneSize"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="activeRwy">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='activeRwy']"/>
  </td>
  <td colspan="2">
  <xsl:value-of select="$trans/t[@o='activeRwy']"/>
  <xsl:value-of select="concat(substring-before($trans/t[@o='rwyDesig'], '|'), rwyDesig/@v, substring-after($trans/t[@o='rwyDesig'], '|'))"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="transitionLvl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat($trans/t[@o='cloud-at'], ' FL ', level/@v)"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="QBB|QBJ">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(altitude/@v, $trans/units[@o='M'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="currentATIS">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='currentATIS']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="ATIS/@v"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="notRecognised|obsInitials">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td colspan="2">
  <xsl:value-of select="@s"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="fcstNotAvbl">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='fcstNotAvbl']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/fcstNotAvblReason[@o=$this/fcstNotAvblReason/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfGround">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='stateOfGround']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(notAvailable)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(stateOfGroundVal)">
   <xsl:value-of select="$trans/stateOfGround[@o=$this/stateOfGroundVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfGroundSnow">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='stateOfGroundSnow']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:if test="boolean(notAvailable)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(stateOfGroundSnowVal)">
   <xsl:value-of select="$trans/stateOfGroundSnow[@o=$this/stateOfGroundSnowVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="snowDepth|snowFall">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr">
   <xsl:value-of select="substring-before($trans/hdr[@o=name($this)], '|')"/>
   <xsl:choose>
    <xsl:when test="boolean(timeBeforeObsSince)">
     <xsl:text> </xsl:text>
     <xsl:apply-templates select="timeBeforeObsSince">
      <xsl:with-param name="period" select="period"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="boolean(period)">
     <xsl:value-of select="$trans/durationSince[@o=$this/period/@v]"/>
    </xsl:when>
   </xsl:choose>
   <xsl:value-of select="substring-after($trans/hdr[@o=name($this)], '|')"/>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$hdr"/>
  </td>
  <xsl:call-template name="precipAmountVal">
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudTypesDrift">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="3"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" rowspan="3">
  <xsl:value-of select="$trans/hdr[@o='cloudTypesDrift']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:text>&#10;&#9;</xsl:text><xsl:value-of select="$trans/t[@o='low']"/>
  <xsl:if test="boolean(cloudTypeLowNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeLowDir)">
   <xsl:value-of select="$trans/compassDir[@o=$this/cloudTypeLowDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1" colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='middle']"/>
  <xsl:if test="boolean(cloudTypeMiddleNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeMiddleDir)">
   <xsl:value-of select="$trans/compassDir[@o=$this/cloudTypeMiddleDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1" colspan="2">
  <xsl:text>&#9;</xsl:text><xsl:value-of select="$trans/t[@o='high']"/>
  <xsl:if test="boolean(cloudTypeHighNA)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighNone)">
   <xsl:value-of select="$trans/t[@o='cloudNone']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighInvisible)">
   <xsl:value-of select="$trans/t[@o='cloudInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudTypeHighDir)">
   <xsl:value-of select="$trans/compassDir[@o=$this/cloudTypeHighDir/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudLocation">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:if test="boolean(cloudTypeNotAvailable)">
   <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(cloudType)">
   <xsl:value-of select="$trans/cloudType[@o=$this/cloudType/@v]"/>
  </xsl:if>
  <xsl:if test="boolean(cloudNone)">
   <xsl:value-of select="concat(', ', $trans/t[@o='cloudNone'])"/>
  </xsl:if>
  <xsl:if test="boolean(cloudInvisible)">
   <xsl:value-of select="concat(', ', $trans/t[@o='cloudInvisible'])"/>
  </xsl:if>
  <xsl:if test="boolean(compassDir)">
   <xsl:value-of select="concat(' ', $trans/compassDir[@o=$this/compassDir/@v])"/>
  </xsl:if>
  <xsl:text>, </xsl:text>
  <xsl:if test="boolean(topsInvisible)">
   <xsl:value-of select="$trans/t[@o='topsInvisible']"/>
  </xsl:if>
  <xsl:if test="boolean(elevationAngle)">
   <xsl:value-of select="$trans/t[@o='elevationAngle']"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="elevationAngle"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   <xsl:text>°</xsl:text>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="group5xxxxNA">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="evapo">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <xsl:variable name="hdr">
   <xsl:choose>
    <xsl:when test="evapoIndicator/@v &lt; 5">
     <xsl:value-of select="$trans/hdr[@o='evaporation']"/>
    </xsl:when>
    <xsl:otherwise>
     <xsl:value-of select="$trans/hdr[@o='evapotranspiration']"/>
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <td nowrap="1">
  <xsl:value-of select="concat(substring-before($hdr, '|'), $trans/durationSince[@o='24h'], substring-after($hdr, '|'))"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="concat(evapoAmount/@v, $trans/units[@o='MM'])"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="evapoIndicator/@v &lt; 5">
    <xsl:value-of select="$trans/hdr[@o='evapoInstrumentation']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='cropEvapotranspiration']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:value-of select="$trans/evapoIndicator[@o=$this/evapoIndicator/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tempChange">
  <xsl:param name="trans"/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="substring-before($trans/hdr[@o='tempChange'], '|')"/>
  <xsl:call-template name="printHoursFromTill">
   <xsl:with-param name="hoursFrom" select="hoursFrom"/>
   <xsl:with-param name="hoursTill" select="hoursTill"/>
   <xsl:with-param name="hoursStr" select="$trans/t[@o='sinceHours']"/>
  </xsl:call-template>
  <xsl:value-of select="substring-after($trans/hdr[@o='tempChange'], '|')"/>
  </td>
  <td nowrap="1">
  <xsl:value-of select="concat(temp/@v, ' °C')"/>
  </td>
  <xsl:text>&#9;&#9;&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:value-of select="concat(format-number(temp/@v div 1.8, '0.#'), ' °F')"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudInfo">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(cloudBaseFrom) or boolean(visVertFrom)">2</xsl:when>
    <xsl:otherwise>1</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:choose>
   <xsl:when test="boolean(cloudBaseNotAvailable) or boolean(cloudBase) or boolean(cloudBaseFrom)">
    <xsl:variable name="hdr" select="$trans/hdr[@o='cloudInfoBase']"/>
    <xsl:value-of select="substring-before($hdr, '|')"/>
    <xsl:call-template name="cloudOktas">
     <xsl:with-param name="cloudOktas" select="cloudOktas"/>
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:call-template>
    <xsl:text> </xsl:text>
    <xsl:choose>
     <xsl:when test="boolean(cloudTypeNotAvailable)">
      <xsl:value-of select="$trans/t[@o='cloudTypeNotAvailable']"/>
     </xsl:when>
     <xsl:otherwise>
      <xsl:value-of select="$trans/cloudType[@o=$this/cloudType/@v]"/>
     </xsl:otherwise>
    </xsl:choose>
    <xsl:if test="boolean(cloudBaseFrom)">
     <xsl:value-of select="concat(' ', $trans/t[@o='level-from'])"/>
    </xsl:if>
    <xsl:value-of select="substring-after($hdr, '|')"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/hdr[@o='visVert']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  <xsl:if test="boolean(cloudBaseNotAvailable)">
   <td nowrap="1" colspan="2">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudBase)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBase"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBase"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  <xsl:if test="boolean(cloudBaseFrom)">
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseFrom"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseFrom"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
  </xsl:if>
  <xsl:if test="boolean(visVert)">
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVert"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:if>
  <xsl:if test="boolean(visVertFrom)">
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVertFrom"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
  </xsl:if>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="boolean(cloudBaseFrom)">
   <tr>
   <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='to']"/></td>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseTo"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="cloudBaseTo"/>
    <xsl:with-param name="unit" select="'FT'"/>
    <xsl:with-param name="factor" select="10"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
  <xsl:if test="boolean(visVertTo)">
   <tr>
   <td nowrap="1"><xsl:value-of select="$trans/hdr[@o='to']"/></td>
   <xsl:call-template name="visibility">
    <xsl:with-param name="notavail" select="$trans/t[@o='visVertNA']"/>
    <xsl:with-param name="visVal" select="visVertTo"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

 <xsl:template name="cloudOktas">
  <xsl:param name="cloudOktas"/>
  <xsl:param name="trans"/>
  <xsl:choose>
   <xsl:when test="boolean($cloudOktas/oktasNotAvailable)">
    <xsl:value-of select="$trans/t[@o='oktasNotAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean($cloudOktas/skyObscured)">
    <xsl:value-of select="$trans/t[@o='SKY_OBSC']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="concat($cloudOktas/oktas/@v, '/8')"/>
    <xsl:if test="$cloudOktas/oktas/@v = 1">
     <xsl:value-of select="$trans/t[@o='lessOktas']"/>
    </xsl:if>
    <xsl:if test="$cloudOktas/oktas/@v = 7">
     <xsl:value-of select="$trans/t[@o='moreOktas']"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template match="precipCharacter">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='precipCharacter']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(noPrecip)">
    <xsl:value-of select="$trans/t[@o='noPrecip']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o=$this/phenomDescr/@v]"/>
    <xsl:if test="boolean(phenomDescr2)">
     <xsl:value-of select="concat(' ', $trans/t[@o=$this/phenomDescr2/@v])"/>
    </xsl:if>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="beginPrecip|endPrecip">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o=name($this)]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(noPrecip)">
    <xsl:value-of select="$trans/t[@o='noPrecip']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:call-template name="printHoursFromTill">
     <xsl:with-param name="hoursFrom" select="hoursFrom"/>
     <xsl:with-param name="hoursTill" select="hoursTill"/>
     <xsl:with-param name="hoursStr" select="$trans/t[@o='hoursAgo']"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="weatherSynopInfo">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:variable name="hdr">
   <xsl:choose>
    <xsl:when test="boolean(timeBeforeObsBegin)">weatherSynopBegin</xsl:when>
    <xsl:when test="boolean(timeBeforeObsEnd)">weatherSynopEnd</xsl:when>
    <xsl:when test="boolean(timeBeforeObsSince)">weatherSynopSince</xsl:when>
    <xsl:otherwise>weatherSynopCharacter</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:value-of select="$trans/hdr[@o=$hdr]"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(phenomVariation)">
    <xsl:value-of select="$trans/t[@o=$this/phenomVariation/@v]"/>
   </xsl:when>
   <xsl:when test="boolean(phenomDescr)">
    <xsl:value-of select="$trans/t[@o=$this/phenomDescr/@v]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:apply-templates select="timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
     <xsl:with-param name="trans" select="$trans"/>
    </xsl:apply-templates>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
  <xsl:param name="period"/>
  <xsl:param name="trans"/>
  <xsl:if test="position() != 1"><xsl:text>, </xsl:text></xsl:if>
  <xsl:choose>
   <xsl:when test="boolean(hoursUnknown)">
    <xsl:variable name="name" select="concat(name(.), 'NA')"/>
    <xsl:value-of select="$trans/t[@o=$name]"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:variable name="hoursStr">
     <xsl:choose>
      <xsl:when test="boolean($period)">
       <xsl:value-of select="$trans/t[@o='hoursAgo']"/>
      </xsl:when>
      <xsl:when test="name(.) = 'timeBeforeObsBegin'">
       <xsl:value-of select="$trans/t[@o='beganAgo']"/>
      </xsl:when>
      <xsl:when test="name(.) = 'timeBeforeObsEnd'">
       <xsl:value-of select="$trans/t[@o='endedAgo']"/>
      </xsl:when>
      <xsl:when test="name(.) = 'timeBeforeObsSince'">
       <xsl:value-of select="$trans/t[@o='sinceHours']"/>
      </xsl:when>
      <xsl:otherwise>
       <xsl:value-of select="$trans/t[@o='hoursAgo']"/>
      </xsl:otherwise>
     </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="printHoursFromTill">
     <xsl:with-param name="hoursFrom" select="hoursFrom"/>
     <xsl:with-param name="hoursTill" select="hoursTill"/>
     <xsl:with-param name="hoursStr" select="$hoursStr"/>
    </xsl:call-template>
   </xsl:otherwise>
  </xsl:choose>
 </xsl:template>

 <xsl:template name="printHoursFromTill">
  <xsl:param name="hoursFrom"/>
  <xsl:param name="hoursTill"/>
  <xsl:param name="hoursStr"/>
  <xsl:value-of select="substring-before($hoursStr, '|')"/>
  <xsl:if test="$hoursFrom/@q = 'isGreater'">&gt;</xsl:if>
  <xsl:value-of select="$hoursFrom/@v"/>
  <xsl:if test="boolean($hoursTill)">
   <xsl:if test="boolean($hoursFrom)"> - </xsl:if>
   <xsl:if test="$hoursTill/@q = 'isLess'">&lt;</xsl:if>
   <xsl:value-of select="$hoursTill/@v"/>
  </xsl:if>
  <xsl:value-of select="substring-after($hoursStr, '|')"/>
 </xsl:template>

 <xsl:template match="highestGust|highestMeanSpeed|meanSpeed|lowestMeanSpeed|highestWind">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="hdr">
   <xsl:value-of select="substring-before($trans/hdr[@o=name($this)], '|')"/>
   <xsl:if test="boolean(measurePeriod)">
    <xsl:value-of select="substring-before($trans/t[@o='duringXMin'], '|')"/>
    <xsl:value-of select="substring(measurePeriod/@v, 1, string-length(measurePeriod/@v) - 1)"/>
    <xsl:value-of select="substring-after($trans/t[@o='duringXMin'], '|')"/>
   </xsl:if>
   <xsl:if test="boolean(hour)">
    <xsl:value-of select="concat(substring-before($trans/t[@o='time-at'], '|'), hour/@v, ':', minute/@v, ' UTC', substring-after($trans/t[@o='time-at'], '|'))"/>
   </xsl:if>
   <xsl:choose>
    <xsl:when test="boolean(timeBeforeObs) or boolean(timeBeforeObsBegin) or boolean(timeBeforeObsEnd) or boolean(timeBeforeObsSince)">
     <xsl:text> </xsl:text>
     <xsl:apply-templates select="timeBeforeObs|timeBeforeObsBegin|timeBeforeObsEnd|timeBeforeObsSince">
      <xsl:with-param name="period" select="period"/>
      <xsl:with-param name="trans" select="$trans"/>
     </xsl:apply-templates>
    </xsl:when>
    <xsl:when test="boolean(period)">
     <xsl:value-of select="$trans/durationSince[@o=$this/period/@v]"/>
    </xsl:when>
   </xsl:choose>
   <xsl:value-of select="substring-after($trans/hdr[@o=name($this)], '|')"/>
  </xsl:variable>
  <xsl:apply-templates select="wind">
   <xsl:with-param name="hdr"   select="$hdr"/>
   <xsl:with-param name="s"     select="@s"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:apply-templates>
 </xsl:template>

 <xsl:template match="precipPeriods">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='precipPeriods']"/>
  </td>
  <td colspan="2">
  <xsl:call-template name="printHoursFromTill">
   <xsl:with-param name="hoursFrom" select="hoursFrom"/>
   <xsl:with-param name="hoursTill" select="hoursTill"/>
   <xsl:with-param name="hoursStr" select="concat('|', $trans/units[@o='H'])"/>
  </xsl:call-template>
  <xsl:choose>
   <xsl:when test="boolean(periodsNA)">
    <xsl:value-of select="$trans/t[@o='periodNotAvailable']"/>
   </xsl:when>
   <xsl:when test="boolean(onePeriod)">
    <xsl:value-of select="$trans/t[@o='onePeriod']"/>
   </xsl:when>
   <xsl:when test="boolean(morePeriods)">
    <xsl:value-of select="$trans/t[@o='morePeriods']"/>
   </xsl:when>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="stateOfSky">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='stateOfSky']"/>
  </td>
  <td colspan="2">
  <xsl:if test="boolean(notAvailable)">
   <xsl:value-of select="$trans/t[@o='notAvailable']"/>
  </xsl:if>
  <xsl:if test="boolean(stateOfSkyVal)">
   <xsl:value-of select="$trans/stateOfSky[@o=$this/stateOfSkyVal/@v]"/>
  </xsl:if>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="cloudBelowStation">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1" rowspan="2"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" rowspan="2">
  <xsl:variable name="hdr" select="$trans/hdr[@o='cloudBelowStation']"/>
  <xsl:value-of select="substring-before($hdr, '|')"/>
  <xsl:call-template name="cloudOktas">
   <xsl:with-param name="cloudOktas" select="cloudOktas"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  <xsl:value-of select="concat(' ', $trans/cloudType[@o=$this/cloudType/@v])"/>
  <xsl:value-of select="substring-after($hdr, '|')"/>
  </td>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudTops"/>
   <xsl:with-param name="unit" select="'M'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  <xsl:text>&#9;&#9;&#9;</xsl:text>
  <td nowrap="1">
  <xsl:call-template name="unitConverter">
   <xsl:with-param name="val" select="cloudTops"/>
   <xsl:with-param name="unit" select="'FT'"/>
   <xsl:with-param name="factor" select="10"/>
   <xsl:with-param name="format" select="'0'"/>
   <xsl:with-param name="trans" select="$trans"/>
  </xsl:call-template>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <tr>
  <td colspan="2">
   <xsl:value-of select="$trans/cloudTopDescr[@o=$this/cloudTopDescr/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="windDir6h">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='windDir6h']"/>
  </td>
  <td colspan="2">
   <xsl:value-of select="$trans/compassDir[@o=$this/compassDir/@v]"/>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="recordTemp|recordTempCity">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <tr>
  <xsl:if test="$method = 'html'">
   <td nowrap="1"><b><xsl:value-of select="@s"/></b></td>
  </xsl:if>
  <td nowrap="1" colspan="3">
  <xsl:value-of select="substring-before($trans/t[@o=name($this)], '|')"/>
  <xsl:if test="recordType/@v = 'HI'">
   <xsl:value-of select="$trans/t[@o='highest']"/>
  </xsl:if>
  <xsl:if test="recordType/@v = 'LO'">
   <xsl:value-of select="$trans/t[@o='lowest']"/>
  </xsl:if>
  <xsl:value-of select="substring-after($trans/t[@o=name($this)], '|')"/>
  <xsl:choose>
   <xsl:when test="(recordType/@v = 'HI' and recordPeriod/@v = 'SE') or (recordType/@v = 'LO' and recordPeriod/@v = 'SL')">
    <xsl:value-of select="$trans/recordPeriod[@o='spring']"/>
   </xsl:when>
   <xsl:when test="(recordType/@v = 'HI' and recordPeriod/@v = 'SL') or (recordType/@v = 'LO' and recordPeriod/@v = 'SE')">
    <xsl:value-of select="$trans/recordPeriod[@o='fall']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/recordPeriod[@o=$this/recordPeriod/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  <xsl:choose>
   <xsl:when test="not(boolean(recordType/@q))">
    <xsl:value-of select="$trans/t[@o='isEqualled']"/>
   </xsl:when>
   <xsl:when test="recordType/@v = 'HI'">
    <xsl:value-of select="$trans/t[@o='isOverrun']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/t[@o='isUnderrun']"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
 </xsl:template>

 <xsl:template match="tideData">
  <xsl:param name="trans"/>
  <xsl:variable name="this" select="."/>
  <xsl:variable name="rows">
   <xsl:choose>
    <xsl:when test="boolean(notAvailable)">1</xsl:when>
    <xsl:otherwise>2</xsl:otherwise>
   </xsl:choose>
  </xsl:variable>
  <xsl:variable name="sign">
   <xsl:if test="tideDeviation/@v &gt; 0">+</xsl:if>
  </xsl:variable>
  <tr>
  <xsl:if test="$method = 'html'">
   <xsl:element name="td">
    <xsl:attribute name="nowrap">1</xsl:attribute>
    <xsl:attribute name="rowspan"><xsl:value-of select="$rows"/></xsl:attribute>
    <b><xsl:value-of select="@s"/></b>
   </xsl:element>
  </xsl:if>
  <td nowrap="1">
  <xsl:value-of select="$trans/hdr[@o='tideData']"/>
  </td>
  <td nowrap="1" colspan="2">
  <xsl:choose>
   <xsl:when test="boolean(notAvailable)">
    <xsl:value-of select="$trans/t[@o='notAvailable']"/>
   </xsl:when>
   <xsl:otherwise>
    <xsl:value-of select="$trans/tideType[@o=$this/tideType/@v]"/>
    <xsl:value-of select="$trans/tideLevel[@o=$this/tideLevel/@v]"/>
   </xsl:otherwise>
  </xsl:choose>
  </td>
  </tr><xsl:text>&#10;</xsl:text>
  <xsl:if test="$rows = 2">
   <tr>
   <td nowrap="1">
   <xsl:value-of select="$trans/hdr[@o='tideDeviation']"/>
   </td>
   <td nowrap="1">
   <xsl:value-of select="$sign"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="tideDeviation"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   <xsl:text>&#9;&#9;&#9;</xsl:text>
   <td nowrap="1">
   <xsl:value-of select="$sign"/>
   <xsl:call-template name="unitConverter">
    <xsl:with-param name="val" select="tideDeviation"/>
    <xsl:with-param name="unit" select="'M'"/>
    <xsl:with-param name="factor" select="1"/>
    <xsl:with-param name="format" select="'0'"/>
    <xsl:with-param name="trans" select="$trans"/>
   </xsl:call-template>
   </td>
   </tr><xsl:text>&#10;</xsl:text>
  </xsl:if>
 </xsl:template>

</xsl:stylesheet>
